BF3_KIT = {1: "Assault", 2: "Engineer", 8: "Recon", 32: "Support"}
BF4_KIT = {
    1: "Assault",
    2: "Engineer",
    32: "Support",
    8: "Recon",
    2048: "Commander",
}
BFH_KIT = {
    2048: "Commander",
    4096: "Enforcer",
    8192: "Mechanic",
    16384: "Operator",
    32768: "Professional",
}
GAMEMODE = {
    1: "CONQUEST",
    2: "RUSH",
    4: "SQRUSH",
    8: "SQDM",
    16: "ONSLAUGHT",
    32: "TEAMDEATHMATCH",
    64: "CONQUESTLARGE",
    128: "CONQUESTASSAULTLARGE",
    256: "CONQUESTASSAULTSMALL",
    512: "GUNMASTER",
    1024: "DOMINATION",
    2048: "TEAMDEATHMATCHC",
    4096: "TEAMDEATHMATCH_FIRETEAM",
    8192: "COMBATMISSION",
    16384: "SECTORCONTROL",
    32768: "FIRETEAM_SURVIVOR",
    65536: "SPORT",
    131072: "TANKSUPERIORITY",
    262144: "OBJECTIVERAID",
    524288: "CAPTURETHEFLAG",
    1048576: "BOMBSQUAD",
    2097152: "OBLITERATION",
    4194304: "SCAVENGER",
    8388608: "AIRSUPERIORITY",
    16777216: "ELIMINATION",
    33554432: "CARRIERASSAULT",
    67108864: "CARRIERASSAULTLARGE",
    134217728: "CARRIERASSAULTSMALL",
    34359738368: "CHAINLINK",
    268435456: "BLOODMONEY",
    2147483648: "HEIST",
    4294967296: "HOTWIRE",
    8589934592: "HIT",
    17179869184: "HOSTAGE",
    536870912: "TURFWARSMALL",
    1073741824: "TURFWARLARGE",
    68719476736: "CONQUESTLADDER",
    137438953472: "SQUADOBLITERATION",
    274877906944: "BOUNTYHUNTER",
    549755813888: "SQUADHEIST",
}
GAMES = ["bfh", "bf4", "bf3"]
GAME_NUMBERS = {
    "bfbc2": 1,
    "bf3": 2,
    "bf1942": 4,
    "bf1943": 8,
    "bfvietnam": 16,
    "bf2": 32,
    "bf2142": 64,
    "bfbc": 128,
    "bfheroes": 256,
    "bfmc": 512,
    "bfp4f": 1024,
    "bf4": 2048,
    "mohw": 4096,
    "bfh": 8192,
}
PLATFORM_NUMBERS = {
    "pc": 1,
    "xbox360": 2,
    "ps3": 4,
    "xbox": 8,
    "ps2": 16,
    "ps4": 32,
    "xboxone": 64,
    "cem_ea_id": 1,
}
REGIONS = {
    1: "NAm",
    2: "SAm",
    4: "AU",
    8: "Africa",
    16: "EU",
    32: "Asia",
    64: "OC",
}
SMALLMODE = {
    1: "CQ",
    2: "RS",
    4: "SQR",
    8: "SQM",
    16: "OS",
    32: "TDM",
    64: "CQL",
    128: "CAL",
    256: "CAS",
    512: "GM",
    1024: "DM",
    2048: "TDC",
    4096: "TDF",
    8192: "CM",
    16384: "SC",
    32768: "FTS",
    65536: "SPRT",
    131072: "TS",
    262144: "ORD",
    524288: "CTF",
    1048576: "BSQ",
    2097152: "OBL",
    4194304: "SCA",
    8388608: "AS",
    16777216: "EL",
    33554432: "CA",
    67108864: "CAL",
    134217728: "CAS",
    34359738368: "CL",
    268435456: "BM",
    2147483648: "HST",
    4294967296: "HW",
    8589934592: "HIT",
    17179869184: "HSTG",
    536870912: "TWS",
    1073741824: "TWL",
    68719476736: "QL",
    137438953472: "SOB",
}
STATS_TEMPLATES = {
    "overviewpopulatestats": "profile.bf3overviewstats",
    "weaponspopulatestats": "profile.bf3weaponsstats",
    "vehiclespopulatestats": "profile.bf3vehiclesstats",
    "warsawdetailedstatspopulate": "profile.warsawdetailedstatspopulate",
    "warsawoverviewpopulate": "profile.warsawoverviewpopulate",
    "warsawweaponspopulatestats": "profile.warsawweaponsstats",
    "warsawvehiclespopulatestats": "profile.warsawvehiclesstats",
    "bfhoverviewpopulate": "profile.bfhoverviewpopulate",
    "bfhweaponspopulatestats": "profile.bfhweaponsstats",
    "bfhvehiclespopulatestats": "profile.bfhvehiclesstats",
}
SLOTS = {
    16: "Full",
    1: "1-5",
    2: "6-10",
    4: "10+",
    8: "Empty",
}
TO_BATTLELOG_PLATFORMS = {
    "pc": "cem_ea_id",
    "psn": "ps3",
    "ps4": "ps3",
    "xboxone": "xbox",
    "xbox": "xbox",
}



MODES = {
    "Conquest0": "Conquest",
    "Rush0": "Rush",
    "BreakThrough0": "Shock Operations",
    "BreakThroughLarge0": "Operations",
    "Possession0": "War pigeons",
    "TugOfWar0": "Frontlines",
    "AirAssault0": "Air assault",
    "Domination0": "Domination",
    "TeamDeathMatch0": "Team Deathmatch",
    "ZoneControl0": "Rush",
}

SMALL_MODES = {
    "Conquest0": "CQ",
    "Rush0": "RS",
    "BreakThrough0": "SO",
    "BreakThroughLarge0": "OP",
    "Possession0": "WP",
    "TugOfWar0": "FL",
    "AirAssault0": "AA",
    "Domination0": "DM",
    "TeamDeathMatch0": "TM",
    "ZoneControl0": "RS",
}

MAPS = {
    "MP_Amiens": "Amiens",
    "MP_Chateau": "Ballroom Blitz",
    "MP_Desert": "Sinai Desert",
    "MP_FaoFortress": "Fao Fortress",
    "MP_Forest": "Argonne Forest",
    "MP_ItalianCoast": "Empire's Edge",
    "MP_MountainFort": "Monte Grappa",
    "MP_Scar": "St Quentin Scar",
    "MP_Suez": "Suez",
    "MP_Giant": "Giant's Shadow",
    "MP_Fields": "Soissons",
    "MP_Graveyard": "Rupture",
    "MP_Underworld": "Fort De Vaux",
    "MP_Verdun": "Verdun Heights",
    "MP_ShovelTown": "Prise de Tahure",
    "MP_Trench": "Nivelle Nights",
    "MP_Bridge": "Brusilov Keep",
    "MP_Islands": "Albion",
    "MP_Ravines": "Łupków Pass",
    "MP_Tsaritsyn": "Tsaritsyn",
    "MP_Valley": "Galicia",
    "MP_Volga": "Volga River",
    "MP_Beachhead": "Cape Helles",
    "MP_Harbor": "Zeebrugge",
    "MP_Naval": "Heligoland Bight",
    "MP_Ridge": "Achi Baba",
    "MP_Alps": "Razor's Edge",
    "MP_Blitz": "London Calling",
    "MP_Hell": "Passchendaele",
    "MP_London": "London Calling: Scourge",
    "MP_Offensive": "River Somme",
    "MP_River": "Caporetto",
}

MAP_IMAGE = {
    "MP_Amiens": "https://cdn.gametools.network/maps/bf1/MP_Amiens_LandscapeLarge-e195589d.jpg",
    "MP_Chateau": "https://cdn.gametools.network/maps/bf1/MP_Chateau_LandscapeLarge-244d5987.jpg",
    "MP_Desert": "https://cdn.gametools.network/maps/bf1/MP_Desert_LandscapeLarge-d8f749da.jpg",
    "MP_FaoFortress": "https://cdn.gametools.network/maps/bf1/MP_FaoFortress_LandscapeLarge-cad1748e.jpg",
    "MP_Forest": "https://cdn.gametools.network/maps/bf1/MP_Forest_LandscapeLarge-dfbbe910.jpg",
    "MP_ItalianCoast": "https://cdn.gametools.network/maps/bf1/MP_ItalianCoast_LandscapeLarge-1503eec7.jpg",
    "MP_MountainFort": "https://cdn.gametools.network/maps/bf1/MP_MountainFort_LandscapeLarge-8a517533.jpg",
    "MP_Scar": "https://cdn.gametools.network/maps/bf1/MP_Scar_LandscapeLarge-ee25fbd6.jpg",
    "MP_Suez": "https://cdn.gametools.network/maps/bf1/MP_Suez_LandscapeLarge-f630fc76.jpg",
    "MP_Giant": "https://cdn.gametools.network/maps/bf1/MP_Giant_LandscapeLarge-dd0b93ef.jpg",
    "MP_Fields": "https://cdn.gametools.network/maps/bf1/MP_Fields_LandscapeLarge-5f53ddc4.jpg",
    "MP_Graveyard": "https://cdn.gametools.network/maps/bf1/MP_Graveyard_LandscapeLarge-bd1012e6.jpg",
    "MP_Underworld": "https://cdn.gametools.network/maps/bf1/MP_Underworld_LandscapeLarge-b6c5c7e7.jpg",
    "MP_Verdun": "https://cdn.gametools.network/maps/bf1/MP_Verdun_LandscapeLarge-1a364063.jpg",
    "MP_ShovelTown": "https://cdn.gametools.network/maps/bf1/MP_Shoveltown_LandscapeLarge-d0aa5920.jpg",
    "MP_Trench": "https://cdn.gametools.network/maps/bf1/MP_Trench_LandscapeLarge-dbd1248f.jpg",
    "MP_Bridge": "https://cdn.gametools.network/maps/bf1/MP_Bridge_LandscapeLarge-5b7f1b62.jpg",
    "MP_Islands": "https://cdn.gametools.network/maps/bf1/MP_Islands_LandscapeLarge-c9d8272b.jpg",
    "MP_Ravines": "https://cdn.gametools.network/maps/bf1/MP_Ravines_LandscapeLarge-1fe0d3f6.jpg",
    "MP_Tsaritsyn": "https://cdn.gametools.network/maps/bf1/MP_Tsaritsyn_LandscapeLarge-2dbd3bf5.jpg",
    "MP_Valley": "https://cdn.gametools.network/maps/bf1/MP_Valley_LandscapeLarge-8dc1c7ca.jpg",
    "MP_Volga": "https://cdn.gametools.network/maps/bf1/MP_Volga_LandscapeLarge-6ac49c25.jpg",
    "MP_Beachhead": "https://cdn.gametools.network/maps/bf1/MP_Beachhead_LandscapeLarge-5a13c655.jpg",
    "MP_Harbor": "https://cdn.gametools.network/maps/bf1/MP_Harbor_LandscapeLarge-d382c7ea.jpg",
    "MP_Naval": "https://cdn.gametools.network/maps/bf1/MP_Naval_LandscapeLarge-dc2e8daf.jpg",
    "MP_Ridge": "https://cdn.gametools.network/maps/bf1/MP_Ridge_LandscapeLarge-8c057a19.jpg",
    "MP_Alps": "https://cdn.gametools.network/maps/bf1/MP_Alps_LandscapeLarge-7ab30e3e.jpg",
    "MP_Blitz": "https://cdn.gametools.network/maps/bf1/MP_Blitz_LandscapeLarge-5e26212f.jpg",
    "MP_Hell": "https://cdn.gametools.network/maps/bf1/MP_Hell_LandscapeLarge-7176911c.jpg",
    "MP_London": "https://cdn.gametools.network/maps/bf1/MP_London_LandscapeLarge-0b51fe46.jpg",
    "MP_Offensive": "https://cdn.gametools.network/maps/bf1/MP_Offensive_LandscapeLarge-6dabdea3.jpg",
    "MP_River": "https://cdn.gametools.network/maps/bf1/MP_River_LandscapeLarge-21443ae9.jpg",
}



KITS = [
    "Anti-Tank",
    "Assault",
    "Engineer",
    "Medic",
    "Spec-Ops",
    "Support",
    "Sniper",
]
MAPS = [
    "Dalian Plant",
    "Daqing Oilfields",
    "Dragon Valley",
    "Fushe Pass",
    "Greatwall",
    "Gulf Of Oman",
    "Highway Tampa",
    "Kubra Dam",
    "Mashtuur City",
    "Midnight Sun",
    "Operation Blue Pearl",
    "Operation Clean Sweep",
    "Operation Harvest",
    "Operation Road Rage",
    "Operation Smoke Screen",
    "Road To Jalalabad",
    "Sharqi Peninsula",
    "Songhua Stalemate",
    "Strike At Karkand",
    "Taraba Quarry",
    "Wake Island 2007",
    "Zatar Wetlands",
]
MODE = {"gpm_cq": "Conquest", "gpm_coop": "Co-op"}
SMALLMODE = {"gpm_cq": "CQ", "gpm_coop": "COOP"}
VEHICLES = ["Armor", "Jet", "Helicopter", "Transport", "Anti-Air", "Ground-Def."]
WEAPONS = [
    "Assault-Rifle",
    "Grenade-Launcher",
    "Carbine",
    "Light Machine Gun",
    "Sniper Rifle",
    "Pistol",
    "Anti-Tank",
    "Sub-Machine Gun",
    "Shotgun",
    "Knife",
    "Defibrillator",
    "Explosives",
    "Grenade",
]



KITS = {
    "assault": "Assault",
    "demo": "Engineer",
    "recon": "Recon",
    "support": "Medic",
}
MAPS = {
    "levels/bc1_harvest_day": "Harvest Day",
    "levels/bc1_oasis": "Oasis",
    "levels/mp_001": "Panama Canal",
    "levels/mp_002": "Valparaiso",
    "levels/mp_003": "Laguna Alta",
    "levels/mp_004": "Isla Inocentes",
    "levels/mp_005": "Atacama Desert",
    "levels/mp_006": "Arica Harbour",
    "levels/mp_007": "White Pass",
    "levels/mp_008": "Nelson Bay",
    "levels/mp_009": "Laguna Presa",
    "levels/mp_012": "Port Valdez",
    "levels/mp_sp_002": "Cold War",
    "levels/mp_sp_005": "Heavy Metal",
    "levels/nam_mp_002": "Vantage Point",
    "levels/nam_mp_003": "Hill 137",
    "levels/nam_mp_005": "Cai Son Temple",
    "levels/nam_mp_006": "Phu Bai Valley",
    "levels/nam_mp_007": "Operation Hastings",
}
MODES = {
    "conquest": "Conquest",
    "rush": "Rush",
    "sqdm": "Squad Deathmatch",
    "sqrush": "Squad Rush",
}
RANKS = [
    "Brigadier General I",
    "1st Lieutenant II",
    "Master Sergeant II",
    "Private II",
    "Chief Warrant Officer I",
    "Colonel III",
    "Warrant Officer III",
    "Sergeant I",
    "Sergeant III",
    "Staff Sergeant III",
    "Sergeant II",
    "First Sergeant I",
    "2nd Lieutenant III",
    "First Sergeant II",
    "Corporal III",
    "Specialist III",
    "Captain II",
    "2nd Lieutenant II",
    "General",
    "Specialist II",
    "Staff Sergeant II",
    "1st Lieutenant I",
    "Corporal I",
    "Master Sergeant III",
    "Captain I",
    "Chief Warrant Officer II",
    "Chief Warrant Officer III",
    "Recruit",
    "Major II",
    "Lieutenant Colonel I",
    "Corporal II",
    "Lieutenant Colonel II",
    "Colonel I",
    "Warrant Officer I",
    "Staff Sergeant I",
    "Private I",
    "Lieutenant Colonel III",
    "Colonel II",
    "Specialist I",
    "Brigadier General II",
    "Major III",
    "Warrant Officer II",
    "Private III",
    "Master Sergeant I",
    "Major I",
    "First Sergeant III",
    "1st Lieutenant III",
    "Brigadier General III",
    "2nd Lieutenant I",
    "Captain III",
    "General of the Army",
]
SMALLMODES = {"conquest": "CQ", "rush": "RS", "sqdm": "SQDM", "sqrush": "SQRS"}
VEHICLES = {
    "aav": {"name": "Anti-Air Gun", "class": "stationary"},
    "ah60": {"name": "UH-60 Transport", "class": "air"},
    "ah64": {"name": "AH-64 Apache", "class": "air"},
    "bmd3": {"name": "BMD-3 Bakhcha", "class": "heavy"},
    "bmda": {"name": "BMD-3 Bakhcha AA", "class": "heavy"},
    "cav": {"name": "Cav", "class": "light"},
    "cobr": {"name": "COBRA 4WD", "class": "light"},
    "havoc": {"name": "Mi-24 Hind", "class": "air"},
    "hmv": {"name": "HMMWV 4WD", "class": "light"},
    "jets": {"name": "Personal Water Craft", "class": "water"},
    "kord": {"name": "KORD HMG", "class": "stationary"},
    "korn": {"name": "KORNET AT", "class": "stationary"},
    "m1a2": {"name": "M1A2 Abrams", "class": "heavy"},
    "m3a3": {"name": "M3A3 Bradley", "class": "heavy"},
    "mi28": {"name": "MI-28 Havoc", "class": "air"},
    "pblb": {"name": "Patrol Boat", "class": "water"},
    "pbrv": {"name": "PBR Vietnam", "class": "water"},
    "qlz8": {"name": "QLZ8 GL", "class": "stationary"},
    "quad": {"name": "Quad Bike", "class": "light"},
    "t90": {"name": "T-90 MBT", "class": "heavy"},
    "tow2": {"name": "TOW2 AT", "class": "stationary"},
    "tru": {"name": "M939 Truck", "class": "light"},
    "uav": {"name": "UAV", "class": "air"},
    "vads": {"name": "VADS", "class": "stationary"},
    "vodn": {"name": "VODNIK 4WD", "class": "light"},
    "xm307": {"name": "XM307 GL", "class": "stationary"},
    "xm312": {"name": "XM312 HMG", "class": "stationary"},
}
WEAPONS = {
    "40mmgl": "40mm Grenade",
    "40mmsg": "40mm Shotgun",
    "9a91": "9A-91 Avtomat",
    "aek": "AEK-971 Vintovka",
    "ak47v": "AK 47 Vietnam",
    "aks74u": "AKS-74U Krinkov",
    "an94": "AN-94 Abakan",
    "atm": "Anti-Tank Mine",
    "aug": "Stg.77 AUG",
    "c4": "C4 Explosive",
    "defi": "Defibrillator",
    "f2000": "F2000 Assault",
    "g3": "G3",
    "gol": "GOL Sniper Magnum",
    "hgr": "Hand Grenade",
    "knv": "Combat Knife",
    "m1": "M1",
    "m136": "M136 AT4",
    "m14v": "M14 Vietnam",
    "m16": "M16A2",
    "m16a1v": "M16A1 Vietnam",
    "m16k": "M16A2 SPECACT",
    "m1911": "WWII M1911 .45",
    "m1a1": "WWII M1A1 Thompson",
    "m21v": "M21 Vietnam",
    "m24": "M24 Sniper",
    "m249": "M249 Saw",
    "m2cg": "M2 Carl Gustav AT",
    "m2v": "M2 Flamethrower Vietnam",
    "m40v": "M40 Vietnam",
    "m416": "M416",
    "m60": "M60 LMG",
    "m60v": "M60 Vietnam",
    "m9": "M9 Pistol",
    "m93r": "M93R Burst",
    "m95": "M95 Sniper",
    "m95k": "M95 Sniper SPECACT",
    "mac10v": "M10 Vietnam",
    "mcs": "870 MCS",
    "mg3": "MG3",
    "mg36": "MG36",
    "mg3k": "MG3 SPECACT",
    "mk14ebr": "M14 Mod 0 Enhanced",
    "mots": "Motion Sensor",
    "mp412": "MP-412 Rex",
    "mp443": "MP-443 Grach",
    "mst": "Mortar Strike",
    "n2k": "NEOSTEAD 2000 Combat",
    "pkm": "PKM LMG",
    "pp2": "PP-2000 Avtomat",
    "ppshv": "PPSh Vietnam",
    "qbu88": "Type 88 Sniper",
    "qju88": "Type 88 LMG",
    "rept": "Repair Tool",
    "rpg7": "RPG-7 AT",
    "rpkv": "RPK Vietnam",
    "s12k": "Saiga 20k Semi",
    "scar": "SCAR-L Carbine",
    "smol": "40mm Smoke Launcher",
    "spas12": "SPAS-12 Combat",
    "sv98": "SV98 Snaiperskaya",
    "svdv": "SVD Sniper Vietnam",
    "svu": "SVU Snaiperskaya Short",
    "trad": "Tracer Dart Gun",
    "tt33v": "TT33 Vietnam",
    "u12": "USAS-12 Auto",
    "ump": "UMP-45",
    "umpk": "UMP-45 SPECACT",
    "uzi": "UZI",
    "uziv": "UZI Vietnam",
    "vss": "VSS Snaiperskaya Special",
    "xm22v": "XM22 Vietnam",
    "xm8": "XM8 Prototype",
    "xm8c": "XM8 Compact",
    "xm8lmg": "XM8 LMG",
}


MAP_LIST = [
    "CAMBODIAN INCURSION",
    "LANDING ZONE ALBANY",
    "OPERATION HASTINGS",
    "SAIGON 1968",
    "FALL OF LANG VEI",
    "OPERATION CEDAR FALLS",
    "OPERATION IRVING",
    "SIEGE OF KHE SAHN",
    "FALL OF SAIGON",
    "OPERATION FLAMING DART",
    "QUẢNG TRỊ",
    "THE IA DRANG VALLEY",
    "HO CHI MINH TRAIL",
    "OPERATION GAME WARDEN",
    "RECLAIMING HUE",
    "WAKE ISLAND",
]
MODE = {
    "conquest": "Conquest",
    "coop": "Co-op",
    "customcombat": "Custom Combat",
    "evolution": "Evolution",
}
SMALLMODE = {
    "conquest": "CQ",
    "coop": "COOP",
    "customcombat": "CC",
    "evolution": "EVOL",
}


MODE = {
    "conquest": "Conquest",
    "coop": "Co-op",
    "ctf": "Capture the Flag",
    "objectivemode": "Objective Mode",
    "tdm": "Team Deathmatch",
}
SMALLMODE = {
    "conquest": "CQ",
    "coop": "COOP",
    "ctf": "CTF",
    "objectivemode": "OBJ",
    "tdm": "TDM",
}


MODES = {
    "CONQ": "Conquest",
    "FRONTLINE": "Frontlines",
    "RUSH": "Rush",
    "DOMI": "Domination",
    "TDM": "Teamdeathmatch",
    "GunGameFFA": "Gungame free-for-all",
    "INFCONQ": "Infantry Conquest",
    "FFA": "Free-for-all",
    "GunGameTeam": "Gungame team",
    "ELI": "Elimination",
}
SMALLMODES = {
    "CONQ": "CQ",
    "FRONTLINE": "FL",
    "RUSH": "RS",
    "DOMI": "DM",
    "TDM": "TDM",
    "INFCONQ": "IQ",
    "GunGameFFA": "GGF",
    "FFA": "FFA",
    "GunGameTeam": "GGT",
    "ELI": "ELI",
}
REGIONS = {
    "Europe_Central": "Europe",
    "America_Central": "America",
    "Japan_Central": "Japan",
    "Australia_Central": "Australia",
    "Brazil_Central": "Brazil",
}



MAP_LIST = [
    "Belgrade",
    "Bridge_at_Remagen",
    "Camp_Gibraltar",
    "Cebere_Landing",
    "Fall_of_Berlin",
    "Highway_Tampa",
    "Liberation_of_Leipzig",
    "Minsk",
    "Molokai",
    "Northern_Mountai_Pass",
    "Operation_Blue_Pearl",
    "Operation_Shingle",
    "Port_Bavaria",
    "Shihua_Taiba",
    "Sidi_Power_Plant",
    "Strike_at_Karkand",
    "Suez_Canal",
    "Tunis_Harbor",
    "Verdun",
    "Wake_Island",
    "Yellow_Knife",
]
MODE = {
    "gpm_cq": "Conquest",
    "gpm_coop": "Conquest Co-op",
    "gpm_sl": "Assault Lines",
    "gpm_ti": "Titan",
    "gpm_ca": "Conquest Assault",
    "gpm_nv": "No Vehicles",
}
SMALLMODE = {
    "gpm_cq": "CQ",
    "gpm_coop": "COOP",
    "gpm_sl": "AL",
    "gpm_ti": "Ti",
    "gpm_ca": "CA",
    "gpm_nv": "NV",
}


PLATFORM = {
    0: "unknown",
    1: "pc",
    2: "ps4",
    3: "xboxone",
    4: "ps5",
    5: "xboxseries",
    6: "common",
    7: "steam",
}
STATS_PLATFORM = {
    1: "pc",
    3: "xboxone",
    2: "ps4",
    5: "xboxseries",
    4: "ps5",
    6: "common",
    7: "steam",
}
PLATFORM_REVERSE = {
    "unknown": 0,
    "pc": 1,
    "ps4": 2,
    "xboxone": 3,
    "ps5": 4,
    "xboxseries": 5,
    "common": 6,
    "steam": 7,
}
PLATFORM_FESL = {
    0: "pc",
    1: "pc",
    2: "ps4",
    3: "xboxone",
    4: "ps4",
    5: "xboxone",
    6: "pc",
    7: "pc",
}
STATS_PLATFORM_REVERSE = {
    "pc": 1,
    "xboxone": 3,
    "ps4": 2,
    "xboxseries": 5,
    "ps5": 4,
    "xbox": 5,
    "psn": 4,
    "steam": 7,
}
REGIONS = {
    "aws-bah": "Asia",
    "aws-bom": "Asia",
    "aws-brz": "South America",
    "aws-cdg": "Europe",
    "aws-cmh": "South America",
    "aws-cpt": "Africa",
    "aws-dub": "Europe",
    "aws-fra": "Europe",
    "aws-hkg": "Asia",
    "aws-iad": "North America",
    "aws-icn": "South America",
    "aws-lhr": "Europe",
    "aws-nrt": "Asia",
    "aws-pdx": "North America",
    "aws-sin": "Asia",
    "aws-sjc": "North America",
    "aws-syd": "Oceania",
}
REGIONSLIST = {
    "asia": ["aws-bah", "aws-bom", "aws-hkg", "aws-nrt", "aws-sin"],
    "nam": ["aws-iad", "aws-pdx", "aws-sjc"],
    "sam": ["aws-brz", "aws-cmh", "aws-icn"],
    "eu": ["aws-cdg", "aws-dub", "aws-fra", "aws-lhr"],
    "afr": ["aws-cpt"],
    "oc": ["aws-syd"],
    "all": [
        "aws-bah",
        "aws-bom",
        "aws-hkg",
        "aws-nrt",
        "aws-sin",
        "aws-iad",
        "aws-pdx",
        "aws-sjc",
        "aws-brz",
        "aws-cmh",
        "aws-icn",
        "aws-cdg",
        "aws-dub",
        "aws-fra",
        "aws-lhr",
        "aws-cpt",
        "aws-syd",
    ],
}
SHORT_REGIONS = {
    "aws-bah": "asia",
    "aws-bom": "asia",
    "aws-brz": "sam",
    "aws-cdg": "eu",
    "aws-cmh": "sam",
    "aws-cpt": "afr",
    "aws-dub": "eu",
    "aws-fra": "eu",
    "aws-hkg": "asia",
    "aws-iad": "nam",
    "aws-icn": "sam",
    "aws-lhr": "eu",
    "aws-nrt": "asia",
    "aws-pdx": "nam",
    "aws-sin": "asia",
    "aws-sjc": "nam",
    "aws-syd": "oc",
}
MAPS = {
    "MP_Abbasid": "Siege of Cairo",
    "MP_Aftermath": "Empire State",
    "MP_Battery": "Iberian Offensive",
    "MP_Capstone": "Liberation Peak",
    "MP_Dumbo": "Manhattan Bridge",
    "MP_FireStorm": "Operation Firestorm",
    "MP_Limestone": "Saints Quarter",
    "MP_Outskirts": "New Sobek City",
    "MP_Tungsten": "Mirak Valley",
}
TO_GAME_MAPS = {
    "siege of cairo": "MP_Abbasid",
    "empire state": "MP_Aftermath",
    "iberian offensive": "MP_Battery",
    "liberation peak": "MP_Capstone",
    "manhattan bridge": "MP_Dumbo",
    "operation firestorm": "MP_FireStorm",
    "saints quarter": "MP_Limestone",
    "new sobek city": "MP_Outskirts",
    "mirak valley": "MP_Tungsten",
}
MAP_TRANSLATION_IDS = {
    "MP_Abbasid": "ID_MP_LVL_ABBASID_NAME",
    "MP_Aftermath": "ID_MP_LVL_AFTERMATH_NAME",
    "MP_Battery": "ID_MP_LVL_BATTERY_NAME",
    "MP_Capstone": "ID_ARRIVAL_MAP_CAPSTONE",
    "MP_Dumbo": "ID_MP_LVL_DUMBO_NAME",
    "MP_FireStorm": "ID_MP_LVL_FIRESTORM_NAME",
    "MP_Limestone": "ID_MP_LVL_LIMESTONE_NAME",
    "MP_Outskirts": "ID_MP_LVL_OUTSKIRTS_NAME",
    "MP_Tungsten": "ID_MP_LVL_TUNGSTEN_NAME",
}
MAP_PICTURES = {
    "MP_Abbasid": "https://cdn.gametools.network/maps/bf6/T_UI_Abbasid_Large_OPT-49a3761a.webp",
    "MP_Aftermath": "https://cdn.gametools.network/maps/bf6/T_UI_Aftermath_Large_OPT-bf883df1.webp",
    "MP_Battery": "https://cdn.gametools.network/maps/bf6/T_UI_Battery_Large_OPT-034d4636.webp",
    "MP_Capstone": "https://cdn.gametools.network/maps/bf6/T_UI_Capstone_Large_OPT-2ccae694.webp",
    "MP_Dumbo": "https://cdn.gametools.network/maps/bf6/T_UI_Dumbo_Large_OPT-20de031f.webp",
    "MP_FireStorm": "https://cdn.gametools.network/maps/bf6/T_UI_Firestorm_Large_OPT-45d582ad.webp",
    "MP_Limestone": "https://cdn.gametools.network/maps/bf6/T_UI_Limestone_Large_OPT-c9160897.webp",
    "MP_Outskirts": "https://cdn.gametools.network/maps/bf6/T_UI_Outskirts_Large_OPT-bf08f756.webp",
    "MP_Tungsten": "https://cdn.gametools.network/maps/bf6/T_UI_Tungsten_Large_OPT-935da06b.webp",
}
SMALLMODES = {
    "Breakthrough0": "BT",
    "BreakthroughSmall0": "BS",
    "ConquestSmall0": "CQ",
    "ModBuilderCustom0": "CM",
    "Rush0": "RS",
    "Conquest0": "CL",
}
MODES = {
    "Breakthrough0": "Breakthrough Large",
    "BreakthroughSmall0": "Breakthrough",
    "ConquestSmall0": "Conquest",
    "ModBuilderCustom0": "Custom",
    "Rush0": "Rush",
    "Conquest0": "Conquest large",
}
TO_GAME_MODES = {
    "breakthrough large": "Breakthrough0",
    "breakthrough": "BreakthroughSmall0",
    "conquest": "ConquestSmall0",
    "custom": "ModBuilderCustom0",
    "rush": "Rush0",
    "conquest large": "Conquest0",
}
STAT_MAPS = {
    "mpabbasid": {
        "mapName": "Siege of Cairo",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Abbasid_Large_OPT-49a3761a.webp",
    },
    "mpaftermath": {
        "mapName": "Empire State",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Aftermath_Large_OPT-bf883df1.webp",
    },
    "mpbattery": {
        "mapName": "Iberian Offensive",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Battery_Large_OPT-034d4636.webp",
    },
    "mpcapstone": {
        "mapName": "Liberation Peak",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Capstone_Large_OPT-2ccae694.webp",
    },
    "mpdumbo": {
        "mapName": "Manhattan Bridge",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Dumbo_Large_OPT-20de031f.webp",
    },
    "mpfirestorm": {
        "mapName": "Operation Firestorm",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Firestorm_Large_OPT-45d582ad.webp",
    },
    "mplimestone": {
        "mapName": "Saints Quarter",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Limestone_Large_OPT-c9160897.webp",
    },
    "mpoutskirts": {
        "mapName": "New Sobek City",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Outskirts_Large_OPT-bf08f756.webp",
    },
    "mptungsten": {
        "mapName": "Mirak Valley",
        "image": "https://cdn.gametools.network/maps/bf6/T_UI_Tungsten_Large_OPT-935da06b.webp",
    },
}



MAPS = {
    "mp_bank": "Bank job",
    "mp_bloodout": "The block",
    "mp_desert": "Dust bowl",
    "mp_downtown": "Downtown",
    "mp_eastside": "Derailed",
    "mp_everglades": "Everglades",
    "mp_growhouse": "Growhouse",
    "mp_hills": "Hollywood heights",
    "mp_offshore": "Riptide",
    "omaha_sp_assault": "Ep. 10: legacy",
    "omaha_sp_chopshop": "Ep. 6: out of business",
    "omaha_sp_copfantasy": "Ep. 1: back to school",
    "omaha_sp_dealgonebad": "Ep. 2: checking out",
    "omaha_sp_desert": "Ep. 8: sovereign land",
    "omaha_sp_escape": "Ep. 5: gauntlet",
    "omaha_sp_everglades": "Ep. 3: gator bait",
    "omaha_sp_heist": "Ep. 9: independence day",
    "omaha_sp_hollywoodhills": "Ep. 7: glass houses",
    "omaha_sp_prologue": "Prologue",
    "omaha_sp_theturn": "Ep. 4: case closed",
    "xp1_mallcops": "Black friday",
    "xp1_nights": "Code blue",
    "xp1_projects": "The beat",
    "xp1_sawmill": "Backwoods",
    "xp25_bank": "Night job",
    "xp25_sawmill": "Night woods",
    "xp2_cargoship": "The docks",
    "xp2_coastal": "Break pointe",
    "xp2_nh_museum": "Museum",
    "xp2_precinct7": "Precinct 7",
    "xp3_border": "Double cross",
    "xp3_cistern": "Diversion",
    "xp3_highway": "Pacific highway",
    "xp3_traindodge": "Train dodge",
    "xp4_alcatraz": "Alcatraz",
    "xp4_cemetery": "Cemetery",
    "xp4_chinatown": "Chinatown",
    "xp4_snowcrash": "Thin ice",
}
MAP_IMAGES = {
    "xp4_cemetery": "https://cdn.gametools.network/maps/bfh/xp4_cemetery-1fc8ff60.png",
    "xp2_cargoship": "https://cdn.gametools.network/maps/bfh/xp2_cargoship-14f35dd7.png",
    "xp25_bank": "https://cdn.gametools.network/maps/bfh/xp25_bank-426c90a6.png",
    "xp1_projects": "https://cdn.gametools.network/maps/bfh/xp1_projects-106b1fa8.png",
    "mp_growhouse": "https://cdn.gametools.network/maps/bfh/mp_growhouse-155870ed.png",
    "xp2_coastal": "https://cdn.gametools.network/maps/bfh/xp2_coastal-cd4ad811.png",
    "mp_offshore": "https://cdn.gametools.network/maps/bfh/mp_offshore-0c4f283b.png",
    "xp25_sawmill": "https://cdn.gametools.network/maps/bfh/xp25_sawmill-82e681f4.png",
    "mp_hills": "https://cdn.gametools.network/maps/bfh/mp_hills-bd854e5f.png",
    "xp3_cistern02": "https://cdn.gametools.network/maps/bfh/xp3_cistern02-89ec81ee.png",
    "mp_bank": "https://cdn.gametools.network/maps/bfh/mp_bank-68ebec2e.png",
    "xp4_snowcrash": "https://cdn.gametools.network/maps/bfh/xp4_snowcrash-3217d5a2.png",
    "xp2_precinct7": "https://cdn.gametools.network/maps/bfh/xp2_precinct7-a8a3e9dc.png",
    "mp_eastside": "https://cdn.gametools.network/maps/bfh/mp_eastside-4f6ff4cb.png",
    "mp_desert05": "https://cdn.gametools.network/maps/bfh/mp_desert05-53ca95fe.png",
    "xp3_highway": "https://cdn.gametools.network/maps/bfh/xp3_highway-461437fb.png",
    "xp1_nights": "https://cdn.gametools.network/maps/bfh/xp1_nights-080a9921.png",
    "mp_glades": "https://cdn.gametools.network/maps/bfh/mp_glades-223b2377.png",
    "xp2_museum02": "https://cdn.gametools.network/maps/bfh/xp2_museum02-6084c272.png",
    "xp4_chinatown": "https://cdn.gametools.network/maps/bfh/xp4_chinatown-45f8cbac.png",
    "xp1_sawmill": "https://cdn.gametools.network/maps/bfh/xp1_sawmill-bfddbf43.png",
    "xp3_traindodge": "https://cdn.gametools.network/maps/bfh/xp3_traindodge-f361cac0.png",
    "mp_downtown": "https://cdn.gametools.network/maps/bfh/mp_downtown-c69bbe19.png",
    "xp3_border": "https://cdn.gametools.network/maps/bfh/xp3_border-68d4906e.png",
    "xp4_alcatraz": "https://cdn.gametools.network/maps/bfh/xp4_alcatraz-1d50f297.png",
    "xp1_mallcops": "https://cdn.gametools.network/maps/bfh/xp1_mallcops-cfeffff8.png",
    "mp_bloodout": "https://cdn.gametools.network/maps/bfh/mp_bloodout-85a5a078.png",
}
WEAPONS = [
    "ro933",
    "mp7",
    "m67-frag",
    "baseball-bat",
    "gold-baton",
    "fn57",
    "scorpion",
    "bowie",
    "arm",
    "gold-hammer",
    "gold-lead-pipe",
    "388-recon",
    "cleaver",
    "golf-club",
    "rpk",
    "m39-emr",
    "gold-scout",
    "decoy",
    "93r",
    "seal",
    "300-knockout",
    "tracking-dart",
    "uzi",
    "trench",
    "karambit",
    "38-snub",
    "410-jury",
    "ro933-300-blk",
    "saiga-12",
    "camera",
    "fmg9",
    "acb-90",
    "hk51",
    "scout-elite",
    "gold-survival",
    "m1a1",
    "44-magnum",
    "nightstick",
    "carbon-fiber",
    "gold-crowbar",
    "throwing-knife",
    "sledge-hammer",
    "870p-magnum",
    "gold-golf-club",
    "ballistic-shield",
    "scar-h",
    "ksg12",
    "p226",
    "shovel",
    "bald-eagle",
    "m5-navy",
    "gold-knife",
    "gold-sledge-hammer",
    "g17-race-pistol",
    "m12s",
    "m320-he",
    "scout",
    "mpx",
    "m79",
    "laser-tripmine",
    "m1903",
    "defibrillator",
    "mammoth-gun",
    "crowbar",
    "mdc",
    "spas-12",
    "improvised-gun",
    "awm",
    "akm",
    "sr-25-ecc",
    "p90",
    "aug-para",
    "ump-9",
    "blackjack",
    "1887",
    "sg553",
    "m320-cs-gas",
    "sp-ar",
    "survival",
    "l85a2",
    "knife",
    "fal",
    "m79-cs-gas",
    "45t",
    "inquisition-sword-red",
    "shank",
    "inquisition-sword-gold",
    "grappling-hook",
    "40-pro",
    "sar-21",
    "m16a3",
    "gas-grenade",
    "hcar",
    "mp9",
    "police-baton",
    "cz-75",
    "357-rs",
    "g17",
    "double-barrel-shotgun",
    "gold-boot",
    "m-45",
    "mx4",
    "lead-pipe",
    "m110k5",
    "sa-58-osw",
    "m5sd",
    "37-stakeout",
    "fire-axe",
    "gold-seal",
    "gold-trench",
    "ro933-m1",
    "ptr-91",
    "m82-416",
    "acwr",
    "92fs",
    "famas",
    "t62-cew",
    "revive",
    "m416",
    "gold-shovel",
    "machete",
    "collapsible-baton",
    "breaching-hammer",
    "m1",
    "k10",
    "ump-45",
    "m98b",
    "aug-a3",
    "molotov",
    "m4",
    "f2000",
    "dual-vz-61",
    "sg510",
    "devil-s-toothpick",
    "mac-10",
    "syndicate-gun",
    "r700-ltr",
    "car-556",
    "breaching-charge",
    "aks-74u",
    "tec-9",
    "sabotage",
    "g36c",
    "gold-machete",
    "boot",
    "aws",
    "a-8s",
    "zipline",
    "rpk-74",
    "repair-tool",
    "incendiary-device",
    "inquisition-sword",
    "socom16",
    "g18c",
    "throwing-knife-gold",
    "gold-fire-axe",
    "saiga-308",
    "mp5k",
    "m1911a1",
]



WEAPONS = {
    "wtypemg42": {
        "type": "Mmg",
        "weaponName": "MG 42",
        "image": "https://cdn.gametools.network/weapons/bfv/MG42-1ca6b52d.png",
    },
    "wtypemg34": {
        "type": "Mmg",
        "weaponName": "MG 34",
        "image": "https://cdn.gametools.network/weapons/bfv/MG34-f447ad5e.png",
    },
    "wtypedarne": {
        "type": "Mmg",
        "weaponName": "M1922 MG",
        "image": "https://cdn.gametools.network/weapons/bfv/Darne-f35be432.png",
    },
    "wtypeg43": {
        "type": "Semi-auto rifle",
        "weaponName": "Gewehr 43",
        "image": "https://cdn.gametools.network/weapons/bfv/Gewehr43-cb742d1a.png",
    },
    "wtypem1car": {
        "type": "Semi-auto rifle",
        "weaponName": "M1A1 Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/M1A1Carbine-0e72e354.png",
    },
    "wtypetsmlesar": {
        "type": "Semi-auto rifle",
        "weaponName": "Turner SMLE",
        "image": "https://cdn.gametools.network/weapons/bfv/TurnerSMLE-75621421.png",
    },
    "wtypems1916": {
        "type": "Semi-auto rifle",
        "weaponName": "Selbstlader 1916",
        "image": "https://cdn.gametools.network/weapons/bfv/Selbstlader1916-f5dcd71a.png",
    },
    "wtypegusvolsar": {
        "type": "Semi-auto rifle",
        "weaponName": "Gewehr 1-5",
        "image": "https://cdn.gametools.network/weapons/bfv/Gewehr15-688f09a9.png",
    },
    "wtypeam42": {
        "type": "Semi-auto rifle",
        "weaponName": "Ag m/42",
        "image": "https://cdn.gametools.network/weapons/bfv/M42-7befb739.png",
    },
    "wtypemasm1944": {
        "type": "Semi-auto rifle",
        "weaponName": "MAS 44",
        "image": "https://cdn.gametools.network/weapons/bfv/Mas44-70764a58.png",
    },
    "wtypewz38": {
        "type": "Semi-auto rifle",
        "weaponName": "Karabin 1938M",
        "image": "https://cdn.gametools.network/weapons/bfv/Wz38M-01b8c70d.png",
    },
    "wtypem1gar": {
        "type": "Semi-auto rifle",
        "weaponName": "M1 Garand",
        "image": "https://cdn.gametools.network/weapons/bfv/M1Garand-3e2b5802.png",
    },
    "wtypem3infraredsniper": {
        "type": "Semi-auto rifle",
        "weaponName": "M3 Infrared",
        "image": "https://cdn.gametools.network/weapons/bfv/M3_Infrared_SniperCarbine-a3fa218b.png",
    },
    "wtypem1941johnsonrifle": {
        "type": "Semi-auto rifle",
        "weaponName": "M1941 Johnson",
        "image": "https://cdn.gametools.network/weapons/bfv/M1941_JohnsonRifle-374730d3.png",
    },
    "wtypemscoutm1916": {
        "type": "Melee",
        "weaponName": "Scout Knife M1916",
        "image": "https://cdn.gametools.network/weapons/bfv/ScoutKnifeM1916-6c8b69f9.png",
    },
    "wtypemkukri": {
        "type": "Melee",
        "weaponName": "Kukri",
        "image": "https://cdn.gametools.network/weapons/bfv/Kukri-63cd4e8e.png",
    },
    "wtypembrarmyknife": {
        "type": "Melee",
        "weaponName": "British Army Jack Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/BritishArmyJackKnife-c6623eae.png",
    },
    "wtypembolousmc": {
        "type": "Melee",
        "weaponName": "Bolo-Guna",
        "image": "https://cdn.gametools.network/weapons/bfv/BoloKnife-5420b66c.png",
    },
    "wtypemislepickaxe": {
        "type": "Melee",
        "weaponName": "Ilse's Pickaxe",
        "image": "https://cdn.gametools.network/weapons/bfv/Pickaxe-17bf1b74.png",
    },
    "wtypeboysat": {
        "type": "Anti-materiel rifle",
        "weaponName": "Boys AT Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/BoysAT-d8f83999.png",
    },
    "wtypepanzerbuchseat": {
        "type": "Anti-materiel rifle",
        "weaponName": "Panzerbüchse 39",
        "image": "https://cdn.gametools.network/weapons/bfv/Panzerbuchse_39-aab3bc76.png",
    },
    "gctlgrenrifle": {
        "type": "Gadget",
        "weaponName": "Frag Grenade Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_SMLE_Grenade-1be05d77.png",
    },
    "gctlrpf": {
        "type": "Gadget",
        "weaponName": "Panzerfaust",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Rocket_Frag_01-05de7537.png",
    },
    "gctdac": {
        "type": "Gadget",
        "weaponName": "Ammo Crate",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Ammo_Crate-40503eb3.png",
    },
    "gcttbin": {
        "type": "Gadget",
        "weaponName": "Spotting Scope",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_Scope-a931f9f1.png",
    },
    "gctlfla": {
        "type": "Gadget",
        "weaponName": "Flare Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_FlareGun-d99b0424.png",
    },
    "gctdsb": {
        "type": "Gadget",
        "weaponName": "Spawn Beacon",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_SpawnBeacon_Single-f2c0bc51.png",
    },
    "gctthrwgsmo": {
        "type": "Gadget",
        "weaponName": "Smoke Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Smoke-150b5665.png",
    },
    "gctthrwgfrag": {
        "type": "Gadget",
        "weaponName": "Frag Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Fuse_UK-51667306.png",
    },
    "gctthrwgfi": {
        "type": "Gadget",
        "weaponName": "Incendiary Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Fire-3bbc4243.png",
    },
    "gctlrpiat": {
        "type": "Gadget",
        "weaponName": "PIAT",
        "image": "https://cdn.gametools.network/weapons/bfv/Launchers_AntiTank_Rocket_Frag_03-b86e6998.png",
    },
    "gctlgrenpistol": {
        "type": "Gadget",
        "weaponName": "AT Grenade Pistol",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Pistol_Frag-7938b179.png",
    },
    "gctlgrensmoke": {
        "type": "Gadget",
        "weaponName": "Smoke Grenade Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_SMLE_Grenade-1be05d77.png",
    },
    "gctthrwgimp": {
        "type": "Gadget",
        "weaponName": "Impact Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Impact_UK-4f81ac0f.png",
    },
    "gctlrf": {
        "type": "Gadget",
        "weaponName": "Fliegerfaust",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiAir_Rocket_Frag-b252fba3.png",
    },
    "gctlrbaz": {
        "type": "Gadget",
        "weaponName": "M1A1 Bazooka",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Rocket_Frag_04-883dd48a.png",
    },
    "gctlgrenpistolcmp": {
        "type": "Gadget",
        "weaponName": "Kampfpistole",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiTank_Pistol_CMP-3f090ca4.png",
    },
    "wtypelewis": {
        "type": "Lmg",
        "weaponName": "Lewis Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/LewisLMG-e0d04932.png",
    },
    "wtypesigke7": {
        "type": "Lmg",
        "weaponName": "KE7",
        "image": "https://cdn.gametools.network/weapons/bfv/SIGKE7-8aa6fea9.png",
    },
    "wtypebren": {
        "type": "Lmg",
        "weaponName": "Bren Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/BRENGun-4c2753f2.png",
    },
    "wtypefg42": {
        "type": "Lmg",
        "weaponName": "FG-42",
        "image": "https://cdn.gametools.network/weapons/bfv/FG42-c6c82ba2.png",
    },
    "wtypels26": {
        "type": "Lmg",
        "weaponName": "LS/26",
        "image": "https://cdn.gametools.network/weapons/bfv/LS26-c1883823.png",
    },
    "wtypemadsenmg": {
        "type": "Lmg",
        "weaponName": "Madsen MG",
        "image": "https://cdn.gametools.network/weapons/bfv/MiniMadsen-b8e2e5c4.png",
    },
    "wtypechau": {
        "type": "Lmg",
        "weaponName": "Chauchat",
        "image": "https://cdn.gametools.network/weapons/bfv/Chauchat-10361a12.png",
    },
    "wtypeBAR1918A2": {
        "type": "Lmg",
        "weaponName": "BAR M1918A2",
        "image": "https://cdn.gametools.network/weapons/bfv/Bar1918_A2-b44ff667.png",
    },
    "wtypetype97MG": {
        "type": "Lmg",
        "weaponName": "Type 97 MG",
        "image": "https://cdn.gametools.network/weapons/bfv/Type97MG-01b69c34.png",
    },
    "wtypetype11lmg": {
        "type": "Lmg",
        "weaponName": "Type 11 LMG",
        "image": "https://cdn.gametools.network/weapons/bfv/Nambu_Type11-166b8aa9.png",
    },
    "wtypebauto5": {
        "type": "Shotgun",
        "weaponName": "12g Automatic",
        "image": "https://cdn.gametools.network/weapons/bfv/12gAutomatic-4344bfef.png",
    },
    "wtypew1897sho": {
        "type": "Shotgun",
        "weaponName": "M1897",
        "image": "https://cdn.gametools.network/weapons/bfv/M1897Shotgun-381578b2.png",
    },
    "wtypeith37sho": {
        "type": "Shotgun",
        "weaponName": "Model 37",
        "image": "https://cdn.gametools.network/weapons/bfv/Model37-e2aff9bb.png",
    },
    "wtypesisho": {
        "type": "Shotgun",
        "weaponName": "Sjögren Shotgun",
        "image": "https://cdn.gametools.network/weapons/bfv/SjogrenShotgun-43cfe31f.png",
    },
    "wtypec96rifle": {
        "type": "Pistol carbine",
        "weaponName": "Trench Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/C96_Carbine-af56338e.png",
    },
    "wtypep08rifle": {
        "type": "Pistol carbine",
        "weaponName": "P08 Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/P08Carbine-5c6a750b.png",
    },
    "wtypefp45l": {
        "type": "Sidearm",
        "weaponName": "Liberator",
        "image": "https://cdn.gametools.network/weapons/bfv/FP45Liberator-0e952d0b.png",
    },
    "wtypewmkiv": {
        "type": "Sidearm",
        "weaponName": "Mk VI Revolver",
        "image": "https://cdn.gametools.network/weapons/bfv/MKVIRevolver-982f4b4b.png",
    },
    "wtypm1911": {
        "type": "Sidearm",
        "weaponName": "M1911",
        "image": "https://cdn.gametools.network/weapons/bfv/M1911-0fd23c61.png",
    },
    "wtypewp38": {
        "type": "Sidearm",
        "weaponName": "P38 Pistol",
        "image": "https://cdn.gametools.network/weapons/bfv/WaltherP38-3813c59d.png",
    },
    "wtyperuby": {
        "type": "Sidearm",
        "weaponName": "Ruby",
        "image": "https://cdn.gametools.network/weapons/bfv/RubyPistol-02727dd8.png",
    },
    "wtypep08": {
        "type": "Sidearm",
        "weaponName": "P08 Pistol",
        "image": "https://cdn.gametools.network/weapons/bfv/LugerP8-ec3e2eca.png",
    },
    "wtypemodel27": {
        "type": "Sidearm",
        "weaponName": "Model 27",
        "image": "https://cdn.gametools.network/weapons/bfv/Model27_Long-4a3efef6.png",
    },
    "wtypm1911s": {
        "type": "Sidearm",
        "weaponName": "M1911 Suppressed",
        "image": "https://cdn.gametools.network/weapons/bfv/M1911_suppressed-ea0651d2.png",
    },
    "wtypestg44": {
        "type": "Assault rifle",
        "weaponName": "StG 44",
        "image": "https://cdn.gametools.network/weapons/bfv/STG44MP44-97548575.png",
    },
    "wtypegusvolar": {
        "type": "Assault rifle",
        "weaponName": "Sturmgewehr 1-5",
        "image": "https://cdn.gametools.network/weapons/bfv/SturmGewehr15-a4740184.png",
    },
    "wtypew1907ar": {
        "type": "Assault rifle",
        "weaponName": "M1907 SF",
        "image": "https://cdn.gametools.network/weapons/bfv/M1907SF-f6ac6f26.png",
    },
    "wtyperib1918": {
        "type": "Assault rifle",
        "weaponName": "Ribeyrolles 1918",
        "image": "https://cdn.gametools.network/weapons/bfv/Ribeyrolles-eed41ed9.png",
    },
    "wtypebredapg": {
        "type": "Assault rifle",
        "weaponName": "Breda M1935 PG",
        "image": "https://cdn.gametools.network/weapons/bfv/BredaPG-a080089a.png",
    },
    "wtypem2car": {
        "type": "Assault rifle",
        "weaponName": "M2 Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/M2Carbine-d6d6efcb.png",
    },
    "wtypedelislerifle": {
        "type": "Bolt action carbine",
        "weaponName": "Commando Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/DeLisleCarabine-18a64a00.png",
    },
    "wtypesmle5": {
        "type": "Bolt action carbine",
        "weaponName": "Jungle Carbine",
        "image": "https://cdn.gametools.network/weapons/bfv/LeeEinfeldNo5-309d1cbe.png",
    },
    "wtypetm1928a1": {
        "type": "Smg",
        "weaponName": "M1928A1",
        "image": "https://cdn.gametools.network/weapons/bfv/Thompson-c31f1ac0.png",
    },
    "wtypemp28": {
        "type": "Smg",
        "weaponName": "MP28",
        "image": "https://cdn.gametools.network/weapons/bfv/MP28-f09c5670.png",
    },
    "wtypesten": {
        "type": "Smg",
        "weaponName": "STEN",
        "image": "https://cdn.gametools.network/weapons/bfv/STENGun-9138fc17.png",
    },
    "wtypeskp31": {
        "type": "Smg",
        "weaponName": "Suomi KP/-31",
        "image": "https://cdn.gametools.network/weapons/bfv/Suomi-2bf82a33.png",
    },
    "wtypmp40": {
        "type": "Smg",
        "weaponName": "MP40",
        "image": "https://cdn.gametools.network/weapons/bfv/MP40-0164787e.png",
    },
    "wtypezk383": {
        "type": "Smg",
        "weaponName": "ZK-383",
        "image": "https://cdn.gametools.network/weapons/bfv/ZK383-374279ef.png",
    },
    "wtypbermod38": {
        "type": "Smg",
        "weaponName": "MAB 38",
        "image": "https://cdn.gametools.network/weapons/bfv/MAB38-e1595a2e.png",
    },
    "wtypet100": {
        "type": "Smg",
        "weaponName": "Type 100",
        "image": "https://cdn.gametools.network/weapons/bfv/Type100_SMG-8b174d3a.png",
    },
    "wtypeM3SMG": {
        "type": "Smg",
        "weaponName": "M3 Grease Gun",
        "image": "https://cdn.gametools.network/weapons/bfv/M3SMG-6cb56d9d.png",
    },
    "wtypenambut2a": {
        "type": "Smg",
        "weaponName": "Type 2A",
        "image": "https://cdn.gametools.network/weapons/bfv/Nambu_Type2A-3b5090e2.png",
    },
    "wtypebwelgun": {
        "type": "Smg",
        "weaponName": "Welgun",
        "image": "https://cdn.gametools.network/weapons/bfv/Welgun-aeb91d41.png",
    },
    "wtypekrag": {
        "type": "Bolt action rifle",
        "weaponName": "Krag–Jørgensen",
        "image": "https://cdn.gametools.network/weapons/bfv/KragJorgensen-30895eb5.png",
    },
    "wtypegewm9530": {
        "type": "Bolt action rifle",
        "weaponName": "Gewehr M95/30",
        "image": "https://cdn.gametools.network/weapons/bfv/Gewehr9530-e1ce76f9.png",
    },
    "wtypesmle4": {
        "type": "Bolt action rifle",
        "weaponName": "Lee-Enfield No.4 Mk I",
        "image": "https://cdn.gametools.network/weapons/bfv/LeeEnfield-85ff8090.png",
    },
    "wtypekar98k": {
        "type": "Bolt action rifle",
        "weaponName": "Kar98k",
        "image": "https://cdn.gametools.network/weapons/bfv/Kar98K-01d381cd.png",
    },
    "wtyperosssrmk3": {
        "type": "Bolt action rifle",
        "weaponName": "Ross Rifle Mk III",
        "image": "https://cdn.gametools.network/weapons/bfv/RossRifle-c930c7e9.png",
    },
    "wtypet99arisaka": {
        "type": "Bolt action rifle",
        "weaponName": "Type 99 Arisaka",
        "image": "https://cdn.gametools.network/weapons/bfv/Type_99_Arisaka-cb8bc4ed.png",
    },
    "wtypek31": {
        "type": "Bolt action rifle",
        "weaponName": "K31/43",
        "image": "https://cdn.gametools.network/weapons/bfv/K3143-910cfbf7.png",
    },
    "wtypersc1918": {
        "type": "Self-loading rifle",
        "weaponName": "RSC",
        "image": "https://cdn.gametools.network/weapons/bfv/RSC-1f58be6c.png",
    },
    "wtypelugersar": {
        "type": "Self-loading rifle",
        "weaponName": "Selbstlader 1906",
        "image": "https://cdn.gametools.network/weapons/bfv/Selbstlader1906-b7f1cea4.png",
    },
    "wtyperemm8slr": {
        "type": "Self-loading rifle",
        "weaponName": "Model 8",
        "image": "https://cdn.gametools.network/weapons/bfv/RemingtonM8-10a6aa82.png",
    },
    "wtypezh29slr": {
        "type": "Self-loading rifle",
        "weaponName": "ZH-29",
        "image": "https://cdn.gametools.network/weapons/bfv/ZH29-62e6adf5.png",
    },
    "wtypes2200": {
        "type": "Mmg",
        "weaponName": "S2-200",
        "image": "https://cdn.gametools.network/weapons/bfv/S2200-d68665c9.png",
    },
    "wtypem1919a6": {
        "type": "Mmg",
        "weaponName": "M1919A6",
        "image": "https://cdn.gametools.network/weapons/bfv/M1919A6-b22db6be.png",
    },
    "wtypemhatchet": {
        "type": "Melee",
        "weaponName": "Hatchet",
        "image": "https://cdn.gametools.network/weapons/bfv/Hatchet-8da526ed.png",
    },
    "wtypemclub": {
        "type": "Melee",
        "weaponName": "Club",
        "image": "https://cdn.gametools.network/weapons/bfv/MeleeClub-41ce6631.png",
    },
    "wtypemshovel": {
        "type": "Melee",
        "weaponName": "Shovel",
        "image": "https://cdn.gametools.network/weapons/bfv/Shovel-767d811e.png",
    },
    "wtypempickaxe": {
        "type": "Melee",
        "weaponName": "Pickaxe",
        "image": "https://cdn.gametools.network/weapons/bfv/Pickaxe-17bf1b74.png",
    },
    "wtypemcricket": {
        "type": "Melee",
        "weaponName": "Cricket Bat",
        "image": "https://cdn.gametools.network/weapons/bfv/CricketBat-b1907335.png",
    },
    "wtypemfsjeager": {
        "type": "Melee",
        "weaponName": "Fallschirmjäger Switchblade",
        "image": "https://cdn.gametools.network/weapons/bfv/Switchblade-f03546ee.png",
    },
    "wtypemsai": {
        "type": "Melee",
        "weaponName": "Sai",
        "image": "https://cdn.gametools.network/weapons/bfv/IronSai-a7911f90.png",
    },
    "wtypemkatana": {
        "type": "Gadget",
        "weaponName": "Katana",
        "image": "https://cdn.gametools.network/weapons/bfv/Katana-273e8e24.png",
    },
    "wtypem30luftd": {
        "type": "Shotgun",
        "weaponName": "M30 Drilling",
        "image": "https://cdn.gametools.network/weapons/bfv/M30LuftwaffeDrilling-93d25c9c.png",
    },
    "wtypetromboncino": {
        "type": "Bolt action carbine",
        "weaponName": "M28 con Tromboncino",
        "image": "https://cdn.gametools.network/weapons/bfv/Tromboncino_M28-e19b76f7.png",
    },
    "wtypemp34s1": {
        "type": "Smg",
        "weaponName": "MP34",
        "image": "https://cdn.gametools.network/weapons/bfv/MP34-82e44afe.png",
    },
    "wtypeemp": {
        "type": "Smg",
        "weaponName": "EMP",
        "image": "https://cdn.gametools.network/weapons/bfv/EMP-5f3287c2.png",
    },
    "gctthrwgat": {
        "type": "Gadget",
        "weaponName": "Anti-Tank Bundle Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiTank_Frag_Impact-8e011bdd.png",
    },
    "wtypemgdagger": {
        "type": "Melee",
        "weaponName": "German Naval Dagger",
        "image": "https://cdn.gametools.network/weapons/bfv/GermanNavalDagger-cdc209da.png",
    },
    "gctdfac": {
        "type": "Gadget",
        "weaponName": "Medical Crate",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Crate-b3f2f42a.png",
    },
    "gctldoubleflare": {
        "type": "Gadget",
        "weaponName": "Doppel-Schuss",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_DoubleBarrelFlareGun-d783a371.png",
    },
    "gctthrwm80cmp": {
        "type": "Gadget",
        "weaponName": "Firecrackers",
        "image": "https://cdn.gametools.network/weapons/bfv/Throwable_M80-b0e5f292.png",
    },
    "gctlgrenrmncmp": {
        "type": "Gadget",
        "weaponName": "RMN50 Rifle Frag",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_RMN_Grenade-9cd222df.png",
    },
    "gctlflmpistol": {
        "type": "Gadget",
        "weaponName": "Pistol Flamethrower",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_AntiPersonal_Pistol_Fire-859644ba.png",
    },
    "wtypesm1912": {
        "type": "Sidearm",
        "weaponName": "Repetierpistole M1912",
        "image": "https://cdn.gametools.network/weapons/bfv/SteyrM1912-19c1c826.png",
    },
    "wtypetype94": {
        "type": "Sidearm",
        "weaponName": "Type 94",
        "image": "https://cdn.gametools.network/weapons/bfv/Type94_Pistol-50a47503.png",
    },
    "wtypewelrod": {
        "type": "Sidearm",
        "weaponName": "Welrod",
        "image": "https://cdn.gametools.network/weapons/bfv/Welrod-f4b59480.png",
    },
    "wtypevickers": {
        "type": "Mmg",
        "weaponName": "VGO",
        "image": "https://cdn.gametools.network/weapons/bfv/VickersK-11cb114e.png",
    },
    "wtypemsolveig": {
        "type": "Melee",
        "weaponName": "Solveig's Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/SolveigKnife-9934570a.png",
    },
    "wtypempoignard": {
        "type": "Melee",
        "weaponName": "Poignard",
        "image": "https://cdn.gametools.network/weapons/bfv/Poignard-c8264c7b.png",
    },
    "gctdfap": {
        "type": "Gadget",
        "weaponName": "Bandages",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Pouch-1db89f38.png",
    },
    "vwepbmb500lb": {
        "type": "Gadget",
        "weaponName": "AT Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_AT_Mine-4bf207e1.png",
    },
    "gctdboomstick": {
        "type": "Gadget",
        "weaponName": "Lunge Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Boomstick-68475909.png",
    },
    "gctlflm": {
        "type": "Gadget",
        "weaponName": "M2 Flamethrower",
        "image": "https://cdn.gametools.network/weapons/bfv/Flamethrower_M2-aa650aed.png",
    },
    "wtypeppks": {
        "type": "Sidearm",
        "weaponName": "PPKS",
        "image": "https://cdn.gametools.network/weapons/bfv/WaltherPPKSuppressed-b8bdb5d5.png",
    },
    "wtypecoupe": {
        "type": "Melee",
        "weaponName": "Coupe Coupe",
        "image": "https://cdn.gametools.network/weapons/bfv/CoupeCoupe-a08d5ff6.png",
    },
    "wtypemfireaxe": {
        "type": "Melee",
        "weaponName": "Fire Axe",
        "image": "https://cdn.gametools.network/weapons/bfv/FireAxe-4f17c94d.png",
    },
    "wtypemlpipe": {
        "type": "Melee",
        "weaponName": "Lever Pipe",
        "image": "https://cdn.gametools.network/weapons/bfv/LeverPipe-310bcfe7.png",
    },
    "wtypemm3sdagg": {
        "type": "Melee",
        "weaponName": "MKIII(S) Elite Combat Dagger",
        "image": "https://cdn.gametools.network/weapons/bfv/FirestormKnife-8a6cc848.png",
    },
    "wtypembottle": {
        "type": "Melee",
        "weaponName": "Broken Bottle",
        "image": "https://cdn.gametools.network/weapons/bfv/BrokenBottle-542adc4d.png",
    },
    "wtypemescapeaxe": {
        "type": "Melee",
        "weaponName": "Escape Axe",
        "image": "https://cdn.gametools.network/weapons/bfv/EscapeAxe-f2181991.png",
    },
    "wtypembarbedbat": {
        "type": "Melee",
        "weaponName": "Barbed Baseball Bat",
        "image": "https://cdn.gametools.network/weapons/bfv/BarbedBaseballBat-fdf73eab.png",
    },
    "wtypemarditi": {
        "type": "Melee",
        "weaponName": "Arditi Dagger",
        "image": "https://cdn.gametools.network/weapons/bfv/ArditiDagger-2883ed9b.png",
    },
    "wtypemokinawamachete": {
        "type": "Melee",
        "weaponName": "Commando Machete",
        "image": "https://cdn.gametools.network/weapons/bfv/OkinawaMachete-d66152d3.png",
    },
    "wtypemustrench": {
        "type": "Melee",
        "weaponName": "Knuckle Duster",
        "image": "https://cdn.gametools.network/weapons/bfv/USTrenchKnife-a80da6fb.png",
    },
    "wtypelionheadsword": {
        "type": "Melee",
        "weaponName": "Lion Head Sword",
        "image": "https://cdn.gametools.network/weapons/bfv/Saber-4e5571ac.png",
    },
    "gctthrwgtype99": {
        "type": "Gadget",
        "weaponName": "Type 99 Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_Type99_Mine-d96f6efd.png",
    },
    "wtypemkabar": {
        "type": "Melee",
        "weaponName": "Combat Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/KABARKnife-7e48ad8b.png",
    },
    "wtypemhachiwari": {
        "type": "Melee",
        "weaponName": "Hachiwari",
        "image": "https://cdn.gametools.network/weapons/bfv/Hachiwari-a5f5884a.png",
    },
    "wtypembonesaw": {
        "type": "Melee",
        "weaponName": "Bone Saw",
        "image": "https://cdn.gametools.network/weapons/bfv/BoneSaw-df104409.png",
    },
    "wtypemuselite03": {
        "type": "Melee",
        "weaponName": "Golden Eagle",
        "image": "https://cdn.gametools.network/weapons/bfv/GoldenEagleKnife-33c9216a.png",
    },
    "gctthrwgsti": {
        "type": "Gadget",
        "weaponName": "Sticky Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiTank_Frag_Sticky-3f809cbe.png",
    },
    "gctthrwgdemo": {
        "type": "Gadget",
        "weaponName": "Demolition Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_Demolition-b1577ee3.png",
    },
    "wtypeppk": {
        "type": "Sidearm",
        "weaponName": "PPK",
        "image": "https://cdn.gametools.network/weapons/bfv/WaltherPPK-6528d353.png",
    },
    "wtypembplank": {
        "type": "Melee",
        "weaponName": "Burned Plank",
        "image": "https://cdn.gametools.network/weapons/bfv/BurnedPlank-112da8c0.png",
    },
    "wtypemrustyk": {
        "type": "Melee",
        "weaponName": "EGW Survival Knife",
        "image": "https://cdn.gametools.network/weapons/bfv/RustyEGWSurvivalKnife-846cfb4d.png",
    },
    "wtypemflightstick": {
        "type": "Melee",
        "weaponName": "Control Stick",
        "image": "https://cdn.gametools.network/weapons/bfv/JapaneseFlightStick-199a01ec.png",
    },
    "gctthrwkn": {
        "type": "Gadget",
        "weaponName": "Kunai",
        "image": "https://cdn.gametools.network/weapons/bfv/Throwable_Kunai-9610d695.png",
    },
    "wtypemfair": {
        "type": "Gadget",
        "weaponName": "Firecrackers",
        "image": "https://cdn.gametools.network/weapons/bfv/Throwable_M80-b0e5f292.png",
    },
    "wtypemk98bay": {
        "type": "Melee",
        "weaponName": "K98 Bayonet",
        "image": "https://cdn.gametools.network/weapons/bfv/K98Bayonet-3d5a1a9a.png",
    },
    "wtypemshillelagh": {
        "type": "Melee",
        "weaponName": "Shillelagh",
        "image": "https://cdn.gametools.network/weapons/bfv/Shillelagh-f9dd5573.png",
    },
    "wtypemchristmasbat": {
        "type": "Melee",
        "weaponName": "The Unexpected Gift",
        "image": "https://cdn.gametools.network/weapons/bfv/ChristmasBaseballBat-a3965f86.png",
    },
    "veqlaunch": {
        "type": "Gadget",
        "weaponName": "Type 99 Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_Type99_Mine-d96f6efd.png",
    },
    "vweplaunchgr": {
        "type": "Gadget",
        "weaponName": "Frag Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Fuse_UK-51667306.png",
    },
    "vwepshellheat": {
        "type": "Gadget",
        "weaponName": "Medical Crate",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Crate-b3f2f42a.png",
    },
    "veqreptrack": {
        "type": "Gadget",
        "weaponName": "Spotting Scope",
        "image": "https://cdn.gametools.network/weapons/bfv/Intel_Scope-a931f9f1.png",
    },
    "rnwtypm1911": {
        "type": "Lmg",
        "weaponName": "Chauchat",
        "image": "https://cdn.gametools.network/weapons/bfv/Chauchat-10361a12.png",
    },
    "veqrepquick": {
        "type": "Gadget",
        "weaponName": "Frag Grenade Rifle",
        "image": "https://cdn.gametools.network/weapons/bfv/Launcher_SMLE_Grenade-1be05d77.png",
    },
    "gcttndlssyrg": {
        "type": "Gadget",
        "weaponName": "Medical Syringe",
        "image": "https://cdn.gametools.network/weapons/bfv/Supply_Medical_Syringe-aee7e9fa.png",
    },
    "wtypemscout": {
        "type": "Gadget",
        "weaponName": "Type 99 Mine",
        "image": "https://cdn.gametools.network/weapons/bfv/Deployable_Type99_Mine-d96f6efd.png",
    },
    "vwepshellap": {
        "type": "Gadget",
        "weaponName": "Impact Grenade",
        "image": "https://cdn.gametools.network/weapons/bfv/Grenade_AntiPersonal_Frag_Impact_UK-4f81ac0f.png",
    },
}
VEHICLES = {
    "taTigISturm": {
        "type": "Tanks",
        "vehicleName": "STURMTIGER",
        "image": "https://cdn.gametools.network/vehicles/bfv/Sturmtiger-3c762491.png",
    },
    "trM3Halft": {
        "type": "Transports",
        "vehicleName": "M3",
        "image": "https://cdn.gametools.network/vehicles/bfv/M3-5dc0e0e7.png",
    },
    "trT48GMC": {
        "type": "Transports",
        "vehicleName": "T48 GMC",
        "image": "https://cdn.gametools.network/vehicles/bfv/M3_T48-1bcaca18.png",
    },
    "trSdKfz": {
        "type": "Transports",
        "vehicleName": "SD. KFZ 251 HALFTRACK",
        "image": "https://cdn.gametools.network/vehicles/bfv/HanomagHalftrack-f86c7ef0.png",
    },
    "trPakWag": {
        "type": "Transports",
        "vehicleName": "SD. KFZ. 251 PAKWAGEN",
        "image": "https://cdn.gametools.network/vehicles/bfv/PakwagenHalftrack-17e871af.png",
    },
    "taChuCro": {
        "type": "Tanks",
        "vehicleName": "CHURCHILL CROCODILE",
        "image": "https://cdn.gametools.network/vehicles/bfv/ChurchillCrocodileTank-d0878564.png",
    },
    "stw6pound": {
        "type": "Stationary",
        "vehicleName": "6 POUNDER",
        "image": "https://cdn.gametools.network/vehicles/bfv/QF6Pounder-a98f3167.png",
    },
    "stwFlak": {
        "type": "Stationary",
        "vehicleName": "FLAK 38",
        "image": "https://cdn.gametools.network/vehicles/bfv/FLAK38AA-45078234.png",
    },
    "stwPak": {
        "type": "Stationary",
        "vehicleName": "PAK 40",
        "image": "https://cdn.gametools.network/vehicles/bfv/PAK40-39c3918d.png",
    },
    "stwMGmg34": {
        "type": "Stationary",
        "vehicleName": "STATIONARY MG34",
        "image": "https://cdn.gametools.network/vehicles/bfv/MG34_Stationary-0d84725f.png",
    },
    "stwMGtype93": {
        "type": "Stationary",
        "vehicleName": "TYPE 93 HMG",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_Type92_HMG-10e95b63.png",
    },
    "stwBofors": {
        "type": "Stationary",
        "vehicleName": "40MM AA",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_40mmAA-91ad1c10.png",
    },
    "stwType10": {
        "type": "Stationary",
        "vehicleName": "TYPE 10",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_Type10-5156b60a.png",
    },
    "taSturmIV0": {
        "type": "Tanks",
        "vehicleName": "STURMGESCHUTZ IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/StugIV-133ce60b.png",
    },
    "taValMkVIII": {
        "type": "Tanks",
        "vehicleName": "VALENTINE MK VIII",
        "image": "https://cdn.gametools.network/vehicles/bfv/valentine-2837c094.png",
    },
    "chaA20": {
        "type": "Tanks",
        "vehicleName": "M8 GREYHOUND",
        "image": "https://cdn.gametools.network/vehicles/bfv/Greyhound-76b96c18.png",
    },
    "stwMGvick": {
        "type": "Stationary",
        "vehicleName": "VICKERS",
        "image": "https://cdn.gametools.network/vehicles/bfv/VickersStationaryMG-eb5f1bdb.png",
    },
    "taPazIV": {
        "type": "Tanks",
        "vehicleName": "PANZER IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/PanzerIVTank_1-adc5c741.png",
    },
    "chaPazIV": {
        "type": "Transports",
        "vehicleName": "GPW",
        "image": "https://cdn.gametools.network/vehicles/bfv/Car_Willys-8ed5b812.png",
    },
    "stwMGm2": {
        "type": "Stationary",
        "vehicleName": "M2 HMG",
        "image": "https://cdn.gametools.network/vehicles/bfv/Stationary_M2_HMG-fd3d7264.png",
    },
    "chaMus": {
        "type": "Tanks",
        "vehicleName": "CHURCHILL GUN CARRIER",
        "image": "https://cdn.gametools.network/vehicles/bfv/ChurchillGunCarrierTank-0725b8c6.png",
    },
    "chaM3Halft": {
        "type": "Tanks",
        "vehicleName": "HACHI",
        "image": "https://cdn.gametools.network/vehicles/bfv/Chi-Ha_RocketLauncher_DeployVersion-13eacf14.png",
    },
    "chaTigI": {
        "type": "Tanks",
        "vehicleName": "PANZER IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/PanzerIVTank_1-adc5c741.png",
    },
    "chaStuka": {
        "type": "Transports",
        "vehicleName": "TYPE 95 CAR",
        "image": "https://cdn.gametools.network/vehicles/bfv/Car_Type95_Kurogane-832fd07e.png",
    },
    "taStagT17E10": {
        "type": "Planes",
        "vehicleName": "P51K Fighter",
        "image": "https://cdn.gametools.network/vehicles/bfv/Mustang-0f157d3d.png",
    },
    "chaChu": {
        "type": "Transports",
        "vehicleName": "TYPE 95 CAR",
        "image": "https://cdn.gametools.network/vehicles/bfv/Car_Type95_Kurogane-832fd07e.png",
    },
    "chaSdKfz": {
        "type": "Planes",
        "vehicleName": "ZERO A6M2",
        "image": "https://cdn.gametools.network/vehicles/bfv/Pac_Zero-32f4d600.png",
    },
    "chaVal": {
        "type": "Planes",
        "vehicleName": "JU-88 C",
        "image": "https://cdn.gametools.network/vehicles/bfv/JU88_C-ad411a79.png",
    },
    "ta": {
        "type": "Tanks",
        "vehicleName": "M8 GREYHOUND",
        "image": "https://cdn.gametools.network/vehicles/bfv/Greyhound-76b96c18.png",
    },
    "chaSher": {
        "type": "Transports",
        "vehicleName": "LCVP",
        "image": "https://cdn.gametools.network/vehicles/bfv/Boat_Higgins-257e601c.png",
    },
    "trv": {
        "type": "Planes",
        "vehicleName": "BF 109 G-2",
        "image": "https://cdn.gametools.network/vehicles/bfv/BF109-c6bd45c6.png",
    },
    "av": {
        "type": "Tanks",
        "vehicleName": "VALENTINE AA MK I",
        "image": "https://cdn.gametools.network/vehicles/bfv/ValentineCrusaderAA-f7c31668.png",
    },
    "chaCor": {
        "type": "Tanks",
        "vehicleName": "CHURCHILL GUN CARRIER",
        "image": "https://cdn.gametools.network/vehicles/bfv/ChurchillGunCarrierTank-0725b8c6.png",
    },
    "alv": {
        "type": "Tanks",
        "vehicleName": "PANZER IV",
        "image": "https://cdn.gametools.network/vehicles/bfv/PanzerIVTank_1-adc5c741.png",
    },
    "wtypestw": {
        "type": "Transports",
        "vehicleName": "DINGHY",
        "image": "https://cdn.gametools.network/vehicles/bfv/Boat_Dinghy-7722932f.png",
    },
    "taStagT17E11": {
        "type": "Transports",
        "vehicleName": "KETTENKRAD",
        "image": "https://cdn.gametools.network/vehicles/bfv/KettenkradLightTransport-1cefde85.png",
    },
}
CLASSES = {
    "assault": {
        "className": "Assault",
        "image": "https://cdn.gametools.network/classes/bf5/white/Assault.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Assault.png",
    },
    "medic": {
        "className": "Medic",
        "image": "https://cdn.gametools.network/classes/bf5/white/Medic.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Medic.png",
    },
    "recon": {
        "className": "Recon",
        "image": "https://cdn.gametools.network/classes/bf5/white/Recon.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Recon.png",
    },
    "support": {
        "className": "Support",
        "image": "https://cdn.gametools.network/classes/bf5/white/Support.png",
        "altImage": "https://cdn.gametools.network/classes/bf5/black/Support.png",
    },
}
STAT_GAMEMODE = {
    "dom": {"gamemodeName": "Domination"},
    "rush": {"gamemodeName": "Rush"},
    "frontlines": {"gamemodeName": "Frontlines"},
    "tdm": {"gamemodeName": "Team Deathmatch"},
    "outp": {"gamemodeName": "Outpost"},
    "bth": {"gamemodeName": "Breakthrough"},
    "conq": {"gamemodeName": "Conquest"},
}
STAT_GAMEMODE_EXTR = {
    "dom": "gm_domination",
    "rush": "gm_rush",
    "frontlines": "gm_frontlines",
    "tdm": "gm_tdm",
    "outp": "gm_outpost",
    "bth": "gm_breakthrough",
    "conq": "gm_conquest",
}
STAT_MAPS = {
    "arcticfjell": {
        "mapName": "Fjell 652",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_ArcticFjell-df3c1290.jpg",
    },
    "arcticfjord": {
        "mapName": "Narvik",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_ArcticFjord-7ba29138.jpg",
    },
    "arras": {
        "mapName": "Arras",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Arras-4b610505.jpg",
    },
    "devastation": {
        "mapName": "Devastation",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Devastation-623dea60.jpg",
    },
    "escaut": {
        "mapName": "Twisted Steel",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Escaut-9764d1fb.jpg",
    },
    "foxhunt": {
        "mapName": "Aerodrome",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_AfricanFox-8ad380a5.jpg",
    },
    "halfaya": {
        "mapName": "Hamada",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_AfricanHalfaya-31165f9b.jpg",
    },
    "rotterdam": {
        "mapName": "Rotterdam",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Rotterdam-55632240.jpg",
    },
    "hannut": {
        "mapName": "Panzerstorm",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Hannut-ebbe7197.jpg",
    },
    "crete": {
        "mapName": "Mercury",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Crete-304a202d.jpg",
    },
    "kalamas": {
        "mapName": "Marita",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Kalamas-c64c8451.jpg",
    },
    "provence": {
        "mapName": "Provence",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_ProvenceXL-a950ad3e.jpg",
    },
    "sandandsea": {
        "mapName": "Al Sudan",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_SandAndSea-f071e6f7.jpg",
    },
    "bunker": {
        "mapName": "Operation Underground",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Bunker-7b518876.jpg",
    },
    "iwojima": {
        "mapName": "Iwo Jima",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_IwoJima-760850fc.jpg",
    },
    "tropicislands": {
        "mapName": "Pacific Storm",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_TropicIslands-9e0a41c3.jpg",
    },
    "wakeisland": {
        "mapName": "Wake Island",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_WakeIsland-3238b455.jpg",
    },
    "jungle": {
        "mapName": "Solomon Islands",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Jungle-714218ce.jpg",
    },
    "libya": {
        "mapName": "Al Marj Encampment",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Libya-bd54b090.jpg",
    },
    "norway": {
        "mapName": "Lofoten Islands",
        "image": "https://cdn.gametools.network/maps/bfv/1080p_MP_Norway-7d6d6300.jpg",
    },
}
FACTIONS = {
    "BFFactionId_FactionGER": {
        "key": "GER",
        "name": "German Empire",
        "shortName": "GER",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionGER.png",
    },
    "BFFactionId_FactionUK": {
        "key": "UK",
        "name": "British Empire",
        "shortName": "UK",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionUK.png",
    },
    "BFFactionId_FactionUSA_Pacific": {
        "key": "USA_Pacific",
        "name": "UNITED STATES OF AMERICA",
        "shortName": "USA",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionUSA_Pacific.png",
    },
    "BFFactionId_FactionJPN": {
        "key": "JPN",
        "name": "Empire of Japan",
        "shortName": "JPN",
        "image": "https://cdn.gametools.network/factions/bfv/BFFactionId_FactionJPN.png",
    },
}
INTERNAL_MAP_NAME = {
    "fjell 652": "MP_ArcticFjell",
    "narvik": "MP_ArcticFjord",
    "arras": "MP_Arras",
    "devastation": "MP_Devastation",
    "twisted steel": "MP_Escaut",
    "aerodrome": "MP_Foxhunt",
    "hamada": "MP_Halfaya",
    "rotterdam": "MP_Rotterdam",
    "panzerstorm": "MP_Hannut",
    "mercury": "MP_Crete",
    "marita": "MP_Kalamas",
    "provence": "MP_Provence",
    "al sudan": "MP_SandAndSea",
    "operation Underground": "MP_Bunker",
    "iwo jima": "MP_IwoJima",
    "pacific storm": "MP_TropicIslands",
    "wake island": "MP_WakeIsland",
    "solomon islands": "MP_Jungle",
    "al marj encampment": "MP_Libya",
    "lofoten islands": "MP_Norway",
}
MAP_FACTIONS = {
    "MP_ArcticFjell": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_ArcticFjord": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Arras": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Devastation": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Escaut": ["BFFactionId_FactionGER", "BFFactionId_FactionUSA_Pacific"],
    "MP_Foxhunt": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Halfaya": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_Rotterdam": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Hannut": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
    "MP_Crete": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Kalamas": ["BFFactionId_FactionGER", "BFFactionId_FactionUK"],
    "MP_Provence": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
    "MP_SandAndSea": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
    "MP_Bunker": ["BFFactionId_FactionUK", "BFFactionId_FactionGER"],
    "MP_IwoJima": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_TropicIslands": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_WakeIsland": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_Jungle": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionJPN"],
    "MP_Libya": ["BFFactionId_FactionUSA_Pacific", "BFFactionId_FactionGER"],
}
SMALLMODES = {
    "Conquest": "CQ",
    "Domination": "DM",
    "TugOfWar": "FL",
    "Rush": "RS",
    "BreakthroughLarge": "OP",
    "Breakthrough": "SO",
    "Possession": "WP",
    "TeamDeathMatch": "TM",
    "ZoneControl": "SD",
    "AirAssault": "AA",
}
WEAPON_LIST = [
    "M1919A6",
    "Gewehr 43",
    "M1A1 Carbine",
    "M1 Garand",
    "Scout Knife M1916",
    "Hatchet",
    "Club",
    "Pickaxe",
    "K98 Bayonet",
    "Frag Grenade Rifle",
    "Sticky Dynamite",
    "Panzerfaust",
    "Bandages",
    "AP Mine",
    "Medical Crate",
    "Spotting Scope",
    "Flare Gun",
    "Smoke Grenade",
    "Frag Grenade",
    "Incendiary Grenade",
    "Smoke Grenade Rifle",
    "Throwing Blade",
    "Medical Syringe",
    "Fliegerfaust",
    "Kunai",
    "KE7",
    "Bren Gun",
    "FG-42",
    "Chauchat",
    "M30 Drilling",
    "M1897",
    "Model 37",
    "Repetierpistole M1912",
    "M1911",
    "P38 Pistol",
    "Ruby",
    "P08 Pistol",
    "StG 44",
    "Sturmgewehr 1-5",
    "Ribeyrolles 1918",
    "M2 Carbine",
    "M1928A1",
    "MP28",
    "STEN",
    "Suomi KP/-31",
    "MP40",
    "Type 100",
    "Krag–Jørgensen",
    "Gewehr M95/30",
    "Lee-Enfield No.4 Mk I",
    "Kar98k",
    "Type 99 Arisaka",
    "Model 8",
    "ZH-29",
]



ALL_BF_GAMES = ["bf2", "bf3", "bf4", "bfh", "bf1", "bf5"]
COOKIE = {"sid": "", "remid": ""}
FRONTEND_GAME_FULLNAME = {
    "tunguska": "Battlefield 1",
    "casablanca": "Battlefield V",
    "kingston": "Battlefield 2042",
    "bf4": "Battlefield 4",
    "bf3": "Battlefield 3",
    "bfh": "Battlefield Hardline",
    "bf2": "Battlefield 2",
    "bfbc2": "Battlefield Bad Company 2",
}
FRONTEND_GAME_TRANSLATION = {
    "tunguska": "bf1",
    "casablanca": "bfv",
    "kingston": "bf2042",
    "bf4": "bf4",
    "bfh": "bfh",
    "bf3": "bf3",
    "bf2": "bf2",
    "bfbc2": "bfbc2",
}
GAMEMODES = {
    "TugOfWar": "Frontlines",
    "Domination": "Domination",
    "Breakthrough": "Shock Operations",
    "Rush": "Rush",
    "BreakthroughLarge": "Operations",
    "Conquest": "Conquest",
    "Possession": "War pigeons",
    "TeamDeathMatch": "Team Deathmatch",
    "AirAssault": "Air assault",
    "ZoneControl": "Rush",
    "Airborne": "Airborne",
    "FinalStand": "Grand Operations",
    "Outpost": "Outpost",
    "RushLarge": "Rush large",
    "Frontlines": "Frontlines",
    "FrontlinesMedium": "Frontlines Medium",
    "SquadConquest": "Squad Conquest",
    "Conquestlarge": "Conquest large",
}
JOINME_GAMES = ["tunguska", "bf1"]
OLD_GAMES = ["bf2hub", "bfbc2"]
PLATOON_ROLES = {
    "role9": "General",
    "role6": "Colonel",
    "role3": "Lieutenant",
    "role0": "Private",
}
SMALLMODES = {
    "Conquest": "CQ",
    "Domination": "DM",
    "TugOfWar": "FL",
    "Rush": "RS",
    "BreakthroughLarge": "OP",
    "Breakthrough": "SO",
    "Possession": "WP",
    "TeamDeathMatch": "TM",
    "ZoneControl": "SD",
    "AirAssault": "AA",
}
SPARTA_COMMON_ALL_STATS_METHODS = [
    "Progression.getWeaponsByPersonaId",
    "Progression.getVehiclesByPersonaId",
    "Platoons.getActivePlatoon",
    "Platoons.getPlatoons",
    "Progression.getFilteredCodexByPersonaId",
    "Progression.getDogtagsByPersonaId",
    "Progression.getMedalsByPersonaId",
]
SPARTA_GAMES = ["tunguska", "casablanca"]
SPARTA_PLATFORMS = {"cem_ea_id": "pc", "ps3": "psn", "xbox": "xbox"}
SPARTA_REGIONS = ["Afr", "AU", "OC", "AC", "SAm", "EU", "NAm", "Asia"]
SPARTA_TITLES = ["pc", "xbox", "psn"]
TEAMNAMES = ["team 2", "team 1"]



MAPS = {
    "MP_001": "Grand Bazaar",
    "MP_003": "Tehran Highway",
    "MP_007": "Caspian Border",
    "MP_011": "Seine Crossing",
    "MP_012": "Operation Firestorm",
    "MP_013": "Damavand Peak",
    "MP_017": "Noshahr Canals",
    "MP_018": "Kharg Island",
    "MP_Subway": "Operation Métro",
    "XP1_001": "Strike at Karkand",
    "XP1_002": "Gulf of Oman",
    "XP1_003": "Sharqi Peninsula",
    "XP1_004": "Wake Island",
    "XP2_Factory": "Scrapmetal",
    "XP2_Office": "Operation 925",
    "XP2_Palace": "Donya Fortress",
    "XP2_Skybar": "Ziba Tower",
    "XP3_Alborz": "Alborz Mountains",
    "XP3_Desert": "Bandar Desert",
    "XP3_Shield": "Armored Shield",
    "XP3_Valley": "Death Valley",
    "XP4_FD": "Markaz Monolith",
    "XP4_Parl": "Azadi Palace",
    "XP4_Quake": "Epicenter",
    "XP4_Rubble": "Talah Market",
    "XP5_001": "Operation Riverside",
    "XP5_002": "Nebandan Flats",
    "XP5_003": "Kiasar Railroad",
    "XP5_004": "Sabalan Pipeline",
}
RANK_NAME = {
    "BF3_ID_P_RANK00_NAME": "RECRUIT",
    "BF3_ID_P_RANK01_NAME": "PRIVATE FIRST CLASS",
    "BF3_ID_P_RANK02_NAME": "PRIVATE FIRST CLASS 1 STAR",
    "BF3_ID_P_RANK03_NAME": "PRIVATE FIRST CLASS 2 STAR",
    "BF3_ID_P_RANK04_NAME": "PRIVATE FIRST CLASS 3 STAR",
    "BF3_ID_P_RANK05_NAME": "LANCE CORPORAL",
    "BF3_ID_P_RANK06_NAME": "LANCE CORPORAL 1 STAR",
    "BF3_ID_P_RANK07_NAME": "LANCE CORPORAL 2 STAR",
    "BF3_ID_P_RANK08_NAME": "LANCE CORPORAL 3 STAR",
    "BF3_ID_P_RANK09_NAME": "CORPORAL",
    "BF3_ID_P_RANK100_NAME": "COLONEL SERVICE STAR 55",
    "BF3_ID_P_RANK101_NAME": "COLONEL SERVICE STAR 56",
    "BF3_ID_P_RANK102_NAME": "COLONEL SERVICE STAR 57",
    "BF3_ID_P_RANK103_NAME": "COLONEL SERVICE STAR 58",
    "BF3_ID_P_RANK104_NAME": "COLONEL SERVICE STAR 59",
    "BF3_ID_P_RANK105_NAME": "COLONEL SERVICE STAR 60",
    "BF3_ID_P_RANK106_NAME": "COLONEL SERVICE STAR 61",
    "BF3_ID_P_RANK107_NAME": "COLONEL SERVICE STAR 62",
    "BF3_ID_P_RANK108_NAME": "COLONEL SERVICE STAR 63",
    "BF3_ID_P_RANK109_NAME": "COLONEL SERVICE STAR 64",
    "BF3_ID_P_RANK10_NAME": "CORPORAL 1 STAR",
    "BF3_ID_P_RANK110_NAME": "COLONEL SERVICE STAR 65",
    "BF3_ID_P_RANK111_NAME": "COLONEL SERVICE STAR 66",
    "BF3_ID_P_RANK112_NAME": "COLONEL SERVICE STAR 67",
    "BF3_ID_P_RANK113_NAME": "COLONEL SERVICE STAR 68",
    "BF3_ID_P_RANK114_NAME": "COLONEL SERVICE STAR 69",
    "BF3_ID_P_RANK115_NAME": "COLONEL SERVICE STAR 70",
    "BF3_ID_P_RANK116_NAME": "COLONEL SERVICE STAR 71",
    "BF3_ID_P_RANK117_NAME": "COLONEL SERVICE STAR 72",
    "BF3_ID_P_RANK118_NAME": "COLONEL SERVICE STAR 73",
    "BF3_ID_P_RANK119_NAME": "COLONEL SERVICE STAR 74",
    "BF3_ID_P_RANK11_NAME": "CORPORAL 2 STAR",
    "BF3_ID_P_RANK120_NAME": "COLONEL SERVICE STAR 75",
    "BF3_ID_P_RANK121_NAME": "COLONEL SERVICE STAR 76",
    "BF3_ID_P_RANK122_NAME": "COLONEL SERVICE STAR 77",
    "BF3_ID_P_RANK123_NAME": "COLONEL SERVICE STAR 78",
    "BF3_ID_P_RANK124_NAME": "COLONEL SERVICE STAR 79",
    "BF3_ID_P_RANK125_NAME": "COLONEL SERVICE STAR 80",
    "BF3_ID_P_RANK126_NAME": "COLONEL SERVICE STAR 81",
    "BF3_ID_P_RANK127_NAME": "COLONEL SERVICE STAR 82",
    "BF3_ID_P_RANK128_NAME": "COLONEL SERVICE STAR 83",
    "BF3_ID_P_RANK129_NAME": "COLONEL SERVICE STAR 84",
    "BF3_ID_P_RANK12_NAME": "CORPORAL 3 STAR",
    "BF3_ID_P_RANK130_NAME": "COLONEL SERVICE STAR 85",
    "BF3_ID_P_RANK131_NAME": "COLONEL SERVICE STAR 86",
    "BF3_ID_P_RANK132_NAME": "COLONEL SERVICE STAR 87",
    "BF3_ID_P_RANK133_NAME": "COLONEL SERVICE STAR 88",
    "BF3_ID_P_RANK134_NAME": "COLONEL SERVICE STAR 89",
    "BF3_ID_P_RANK135_NAME": "COLONEL SERVICE STAR 90",
    "BF3_ID_P_RANK136_NAME": "COLONEL SERVICE STAR 91",
    "BF3_ID_P_RANK137_NAME": "COLONEL SERVICE STAR 92",
    "BF3_ID_P_RANK138_NAME": "COLONEL SERVICE STAR 93",
    "BF3_ID_P_RANK139_NAME": "COLONEL SERVICE STAR 94",
    "BF3_ID_P_RANK13_NAME": "SERGEANT",
    "BF3_ID_P_RANK140_NAME": "COLONEL SERVICE STAR 95",
    "BF3_ID_P_RANK141_NAME": "COLONEL SERVICE STAR 96",
    "BF3_ID_P_RANK142_NAME": "COLONEL SERVICE STAR 97",
    "BF3_ID_P_RANK143_NAME": "COLONEL SERVICE STAR 98",
    "BF3_ID_P_RANK144_NAME": "COLONEL SERVICE STAR 99",
    "BF3_ID_P_RANK145_NAME": "COLONEL SERVICE STAR 100",
    "BF3_ID_P_RANK14_NAME": "SERGEANT 1 STAR",
    "BF3_ID_P_RANK15_NAME": "SERGEANT 2 STAR",
    "BF3_ID_P_RANK16_NAME": "SERGEANT 3 STAR",
    "BF3_ID_P_RANK17_NAME": "STAFF SERGEANT",
    "BF3_ID_P_RANK18_NAME": "STAFF SERGEANT 1 STAR",
    "BF3_ID_P_RANK19_NAME": "STAFF SERGEANT 2 STAR",
    "BF3_ID_P_RANK20_NAME": "GUNNERY SERGEANT",
    "BF3_ID_P_RANK21_NAME": "GUNNERY SERGEANT 1 STAR",
    "BF3_ID_P_RANK22_NAME": "GUNNERY SERGEANT 2 STAR",
    "BF3_ID_P_RANK23_NAME": "MASTER SERGEANT",
    "BF3_ID_P_RANK24_NAME": "MASTER SERGEANT 1 STAR",
    "BF3_ID_P_RANK25_NAME": "MASTER SERGEANT 2 STAR",
    "BF3_ID_P_RANK26_NAME": "FIRST SERGEANT",
    "BF3_ID_P_RANK27_NAME": "FIRST SERGEANT 1 STAR",
    "BF3_ID_P_RANK28_NAME": "FIRST SERGEANT 2 STAR",
    "BF3_ID_P_RANK29_NAME": "MASTER GUNNERY SERGEANT",
    "BF3_ID_P_RANK30_NAME": "MASTER GUNNERY SERGEANT 1 STAR",
    "BF3_ID_P_RANK31_NAME": "MASTER GUNNERY SERGEANT 2 STAR",
    "BF3_ID_P_RANK32_NAME": "SERGEANT MAJOR",
    "BF3_ID_P_RANK33_NAME": "SERGEANT MAJOR 1 STAR",
    "BF3_ID_P_RANK34_NAME": "SERGEANT MAJOR 2 STAR",
    "BF3_ID_P_RANK35_NAME": "WARRANT OFFICER ONE",
    "BF3_ID_P_RANK36_NAME": "CHIEF WARRANT OFFICER TWO",
    "BF3_ID_P_RANK37_NAME": "CHIEF WARRANT OFFICER THREE",
    "BF3_ID_P_RANK38_NAME": "CHIEF WARRANT OFFICER FOUR",
    "BF3_ID_P_RANK39_NAME": "CHIEF WARRANT OFFICER FIVE",
    "BF3_ID_P_RANK40_NAME": "SECOND LIEUTENANT",
    "BF3_ID_P_RANK41_NAME": "FIRST LIEUTENANT",
    "BF3_ID_P_RANK42_NAME": "CAPTAIN",
    "BF3_ID_P_RANK43_NAME": "MAJOR",
    "BF3_ID_P_RANK44_NAME": "LIEUTENANT COLONEL",
    "BF3_ID_P_RANK45_NAME": "COLONEL",
    "BF3_ID_P_RANK46_NAME": "COLONEL SERVICE STAR 1",
    "BF3_ID_P_RANK47_NAME": "COLONEL SERVICE STAR 2",
    "BF3_ID_P_RANK48_NAME": "COLONEL SERVICE STAR 3",
    "BF3_ID_P_RANK49_NAME": "COLONEL SERVICE STAR 4",
    "BF3_ID_P_RANK50_NAME": "COLONEL SERVICE STAR 5",
    "BF3_ID_P_RANK51_NAME": "COLONEL SERVICE STAR 6",
    "BF3_ID_P_RANK52_NAME": "COLONEL SERVICE STAR 7",
    "BF3_ID_P_RANK53_NAME": "COLONEL SERVICE STAR 8",
    "BF3_ID_P_RANK54_NAME": "COLONEL SERVICE STAR 9",
    "BF3_ID_P_RANK55_NAME": "COLONEL SERVICE STAR 10",
    "BF3_ID_P_RANK56_NAME": "COLONEL SERVICE STAR 11",
    "BF3_ID_P_RANK57_NAME": "COLONEL SERVICE STAR 12",
    "BF3_ID_P_RANK58_NAME": "COLONEL SERVICE STAR 13",
    "BF3_ID_P_RANK59_NAME": "COLONEL SERVICE STAR 14",
    "BF3_ID_P_RANK60_NAME": "COLONEL SERVICE STAR 15",
    "BF3_ID_P_RANK61_NAME": "COLONEL SERVICE STAR 16",
    "BF3_ID_P_RANK62_NAME": "COLONEL SERVICE STAR 17",
    "BF3_ID_P_RANK63_NAME": "COLONEL SERVICE STAR 18",
    "BF3_ID_P_RANK64_NAME": "COLONEL SERVICE STAR 19",
    "BF3_ID_P_RANK65_NAME": "COLONEL SERVICE STAR 20",
    "BF3_ID_P_RANK66_NAME": "COLONEL SERVICE STAR 21",
    "BF3_ID_P_RANK67_NAME": "COLONEL SERVICE STAR 22",
    "BF3_ID_P_RANK68_NAME": "COLONEL SERVICE STAR 23",
    "BF3_ID_P_RANK69_NAME": "COLONEL SERVICE STAR 24",
    "BF3_ID_P_RANK70_NAME": "COLONEL SERVICE STAR 25",
    "BF3_ID_P_RANK71_NAME": "COLONEL SERVICE STAR 26",
    "BF3_ID_P_RANK72_NAME": "COLONEL SERVICE STAR 27",
    "BF3_ID_P_RANK73_NAME": "COLONEL SERVICE STAR 28",
    "BF3_ID_P_RANK74_NAME": "COLONEL SERVICE STAR 29",
    "BF3_ID_P_RANK75_NAME": "COLONEL SERVICE STAR 30",
    "BF3_ID_P_RANK76_NAME": "COLONEL SERVICE STAR 31",
    "BF3_ID_P_RANK77_NAME": "COLONEL SERVICE STAR 32",
    "BF3_ID_P_RANK78_NAME": "COLONEL SERVICE STAR 33",
    "BF3_ID_P_RANK79_NAME": "COLONEL SERVICE STAR 34",
    "BF3_ID_P_RANK80_NAME": "COLONEL SERVICE STAR 35",
    "BF3_ID_P_RANK81_NAME": "COLONEL SERVICE STAR 36",
    "BF3_ID_P_RANK82_NAME": "COLONEL SERVICE STAR 37",
    "BF3_ID_P_RANK83_NAME": "COLONEL SERVICE STAR 38",
    "BF3_ID_P_RANK84_NAME": "COLONEL SERVICE STAR 39",
    "BF3_ID_P_RANK85_NAME": "COLONEL SERVICE STAR 40",
    "BF3_ID_P_RANK86_NAME": "COLONEL SERVICE STAR 41",
    "BF3_ID_P_RANK87_NAME": "COLONEL SERVICE STAR 42",
    "BF3_ID_P_RANK88_NAME": "COLONEL SERVICE STAR 43",
    "BF3_ID_P_RANK89_NAME": "COLONEL SERVICE STAR 44",
    "BF3_ID_P_RANK90_NAME": "COLONEL SERVICE STAR 45",
    "BF3_ID_P_RANK91_NAME": "COLONEL SERVICE STAR 46",
    "BF3_ID_P_RANK92_NAME": "COLONEL SERVICE STAR 47",
    "BF3_ID_P_RANK93_NAME": "COLONEL SERVICE STAR 48",
    "BF3_ID_P_RANK94_NAME": "COLONEL SERVICE STAR 49",
    "BF3_ID_P_RANK95_NAME": "COLONEL SERVICE STAR 50",
    "BF3_ID_P_RANK96_NAME": "COLONEL SERVICE STAR 51",
    "BF3_ID_P_RANK97_NAME": "COLONEL SERVICE STAR 52",
    "BF3_ID_P_RANK98_NAME": "COLONEL SERVICE STAR 53",
    "BF3_ID_P_RANK99_NAME": "COLONEL SERVICE STAR 54",
}
WEAPONS = [
    "RPK",
    "FGM-148 JAVELIN",
    "SKS",
    "M39",
    "Pecheneg",
    "M416",
    "G36C",
    "M412 Rex",
    "SV98",
    "RPG-7",
    "Crossbow kobra",
    "Glock 17",
    "AN94",
    "M60",
    "M1911 LIT",
    "SCAR",
    "MK11",
    "Glock 18 Silenced",
    "UMP",
    "PDR",
    "M98B",
    "M9 Silenced",
    "XP2 L86A1",
    "M40A5",
    "USAS",
    "XP2 LSAT",
    "XP1 QBB95",
    "XP1 HK53",
    "M1911",
    "XP1 QBU88",
    "M16A4",
    "XP2 AUG",
    "M1014",
    "AEK971",
    "G3A4",
    "Taurus 44",
    "AKS74U",
    "Glock 17 Silenced",
    "Underslung Launcher",
    "Glock 18",
    "F2000",
    "M1911 SILENCED",
    "MP443 LIT",
    "Taurus 44 scoped",
    "XP1 L96",
    "XP1 FAMAS",
    "M249",
    "A91",
    "AS-VAL",
    "P90",
    "M93R",
    "XP1 PP19",
    "870",
    "XP2 HK417",
    "MP443 Silenced",
    "M9 Flashlight",
    "PP2000",
    "XP2 SPAS12",
    "MP7",
    "AK74M",
    "Underslung Shotgun",
    "MP 443",
    "Crossbow Scoped",
    "Saiga",
    "XP1 L85A2",
    "DAO",
    "M27",
    "SG553",
    "Type88",
    "SA-18 IGLA AA",
    "Knife",
    "M240",
    "XP2 MTAR-21",
    "SVD",
    "KH2002",
    "XP1 Jackhammer",
    "XP2 SCARL",
    "M1911 Tactical",
    "XP2 MP5K",
    "FIM-92 STINGER AA",
    "M9",
    "XP2 ACR",
    "M4A1",
    "XP2 JNG90",
    "XP1 QBZ95B",
    "XP1 MG36",
    "Mk153 SMAW",
]
INTERNAL_MAP_NAME = {
    "MP_001": "Grand Bazaar",
    "MP_003": "Tehran Highway",
    "MP_007": "Caspian Border",
    "MP_011": "Seine Crossing",
    "MP_012": "Operation Firestorm",
    "MP_013": "Damavand Peak",
    "MP_017": "Noshahr Canals",
    "MP_018": "Kharg Island",
    "MP_Subway": "Operation Métro",
    "XP1_001": "Strike at Karkand",
    "XP1_002": "Gulf of Oman",
    "XP1_003": "Sharqi Peninsula",
    "XP1_004": "Wake Island",
    "XP2_Factory": "Scrapmetal",
    "XP2_Office": "Operation 925",
    "XP2_Palace": "Donya Fortress",
    "XP2_Skybar": "Ziba Tower",
    "XP3_Alborz": "Alborz Mountains",
    "XP3_Desert": "Bandar Desert",
    "XP3_Shield": "Armored Shield",
    "XP3_Valley": "Death Valley",
    "XP4_FD": "Markaz Monolith",
    "XP4_Parl": "Azadi Palace",
    "XP4_Quake": "Epicenter",
    "XP4_Rubble": "Talah Market",
    "XP5_001": "Operation Riverside",
    "XP5_002": "Nebandan Flats",
    "XP5_003": "Kiasar Railroad",
    "XP5_004": "Sabalan Pipeline",
}
